@@ -63,8 +63,6 @@ void FavIconTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
 
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
     // To let ctest exit, we shouldn't start kio_http_cache_cleaner
     qputenv("KIO_DISABLE_CACHE_CLEANER", "yes");
     // To get KJob::errorString() in English
@@ -271,7 +269,7 @@ void FavIconTest::concurrentRequestsShouldWork()
     const int numThreads = 3;
     QThreadPool tp;
     tp.setMaxThreadCount(numThreads);
-    QVector<QFuture<QString>> futures(numThreads);
+    QList<QFuture<QString>> futures(numThreads);
     for (int i = 0; i < numThreads; ++i) {
         futures[i] = QtConcurrent::run(&tp, getAltIconUrl);
     }
