@@ -44,6 +44,17 @@ void KFileItemTest::testPermissionsString()
     QCOMPARE((uint)fileItem.permissions(), (uint)0604);
     QCOMPARE(fileItem.permissionsString(), QStringLiteral("-rw----r--"));
     QVERIFY(fileItem.isReadable());
+    QCOMPARE(fileItem.getStatusBarInfo(), QStringLiteral("afile (empty document, 0 B)"));
+
+    // Folder
+    QVERIFY(QDir(tempDir.path())
+                .mkdir(QStringLiteral("afolder"),
+                       QFile::ReadOwner | QFile::WriteOwner | QFile::ExeUser | QFile::ReadGroup | QFile::ExeGroup | QFile::ReadOther | QFile::ExeOther));
+    QFile folderFile(tempDir.path() + "/afolder");
+    KFileItem folderItem(QUrl::fromLocalFile(folderFile.fileName()), QString(), KFileItem::Unknown);
+    QCOMPARE(folderItem.permissionsString(), QStringLiteral("drwxr-xr-x")); // 655
+    QVERIFY(folderItem.isReadable());
+    QCOMPARE(folderItem.getStatusBarInfo(), QStringLiteral("afolder (folder)"));
 
     // Symlink to file
     QString symlink = tempDir.path() + "/asymlink";
@@ -55,6 +66,22 @@ void KFileItemTest::testPermissionsString()
     // This is actually useful though; the user sees it's a link, and can check if he can read the [target] file.
     QCOMPARE(symlinkItem.permissionsString(), QStringLiteral("lrw----r--"));
     QVERIFY(symlinkItem.isReadable());
+    QCOMPARE(symlinkItem.getStatusBarInfo(), QStringLiteral("asymlink (empty document, Link to %1/afile)").arg(tempDir.path()));
+
+#ifdef Q_OS_UNIX
+    // relative Symlink to a file
+    QFile relativeFile("../afile");
+    QString relativeSymlink = tempDir.path() + "/afolder/relative-symlink";
+    QVERIFY(::symlink("../afile", relativeSymlink.toLatin1()) == 0);
+    QUrl relativeSymlinkUrl = QUrl::fromLocalFile(relativeSymlink);
+    KFileItem relativeSymlinkItem(relativeSymlinkUrl, QString(), KFileItem::Unknown);
+    QCOMPARE((uint)relativeSymlinkItem.permissions(), (uint)0604);
+    // This is a bit different from "ls -l": we get the 'l' but we see the permissions of the target.
+    // This is actually useful though; the user sees it's a link, and can check if he can read the [target] file.
+    QCOMPARE(relativeSymlinkItem.permissionsString(), QStringLiteral("lrw----r--"));
+    QVERIFY(relativeSymlinkItem.isReadable());
+    QCOMPARE(relativeSymlinkItem.getStatusBarInfo(), QStringLiteral("relative-symlink (empty document, Link to %1/afile)").arg(tempDir.path()));
+#endif
 
     // Symlink to directory (#162544)
     QVERIFY(QFile::remove(symlink));
@@ -62,6 +89,12 @@ void KFileItemTest::testPermissionsString()
     KFileItem symlinkToDirItem(symlinkUrl, QString(), KFileItem::Unknown);
     QCOMPARE((uint)symlinkToDirItem.permissions(), (uint)0700);
     QCOMPARE(symlinkToDirItem.permissionsString(), QStringLiteral("lrwx------"));
+    QCOMPARE(symlinkToDirItem.getStatusBarInfo(), QStringLiteral("asymlink (folder, Link to %1)").arg(tempDir.path()));
+
+    // unkwnown file
+    QFile unkwnownFile(tempDir.path() + "/unkwnown_file");
+    KFileItem unkwnownfileItem(QUrl::fromLocalFile(unkwnownFile.fileName()), QString(), KFileItem::Unknown);
+    QCOMPARE(unkwnownfileItem.getStatusBarInfo(), QStringLiteral("unkwnown_file (unknown)"));
 }
 
 void KFileItemTest::testNull()
@@ -73,6 +106,7 @@ void KFileItemTest::testNull()
     null = fileItem; // ok, now 'null' isn't so null anymore
     QVERIFY(!null.isNull());
     QVERIFY(null.isReadable());
+    QVERIFY(!null.isWritable());
     QVERIFY(!null.isHidden());
 }
 
@@ -81,6 +115,7 @@ void KFileItemTest::testDoesNotExist()
     KFileItem fileItem(QUrl::fromLocalFile(QStringLiteral("/doesnotexist")), QString(), KFileItem::Unknown);
     QVERIFY(!fileItem.isNull());
     QVERIFY(!fileItem.isReadable());
+    QVERIFY(!fileItem.isWritable());
     QVERIFY(fileItem.user().isEmpty());
     QVERIFY(fileItem.group().isEmpty());
 }
@@ -136,6 +171,26 @@ void KFileItemTest::testMove()
     QCOMPARE(fileItem2.name(), QStringLiteral("two"));
 }
 
+void KFileItemTest::testMimeTypeCtor()
+{
+    KFileItem fileItem;
+
+    fileItem = KFileItem(QUrl::fromLocalFile(QStringLiteral("/one")), QString("inode/directory"));
+    QVERIFY(fileItem.isDir());
+    QVERIFY(fileItem.isMimeTypeKnown());
+
+    fileItem = KFileItem(QUrl::fromLocalFile(QStringLiteral("/one")), QString("image/jpeg"));
+    QVERIFY(!fileItem.isDir());
+    QVERIFY(fileItem.isMimeTypeKnown());
+
+    fileItem = KFileItem(QUrl::fromLocalFile(QStringLiteral("/one.txt")), QString("inode/directory"));
+    QVERIFY(fileItem.isDir());
+    QVERIFY(fileItem.isMimeTypeKnown());
+
+    fileItem = KFileItem(QUrl::fromLocalFile(QStringLiteral("/one.txt")), QString(" "));
+    QVERIFY(!fileItem.isMimeTypeKnown());
+}
+
 void KFileItemTest::testBasic()
 {
     QTemporaryFile file;
@@ -446,6 +501,32 @@ void KFileItemTest::testRefresh()
     QVERIFY(symlinkToDirItem.isLink());
 }
 
+void KFileItemTest::testExists()
+{
+    QTest::failOnWarning(QRegularExpression(".?"));
+
+    KFileItem dummy;
+    QVERIFY(!dummy.exists());
+
+    QTemporaryFile f;
+    QVERIFY(f.open());
+    f.close();
+    const auto fileName = f.fileName();
+    dummy = KFileItem(QUrl::fromLocalFile(fileName));
+    dummy.refresh();
+    QVERIFY(dummy.exists());
+
+    QVERIFY(QFile::remove(fileName));
+    QVERIFY(dummy.exists());
+    dummy.refresh();
+    QVERIFY(!dummy.exists());
+
+    dummy = KFileItem(QUrl::fromLocalFile(fileName));
+    // this should trigger a warning
+    QTest::ignoreMessage(QtMsgType::QtWarningMsg, QRegularExpression("^KFileItem: exists called when not initialised QUrl"));
+    QVERIFY(!dummy.exists());
+}
+
 void KFileItemTest::testDotDirectory()
 {
     QTemporaryDir tempDir;
@@ -734,7 +815,9 @@ void KFileItemTest::testIsReadable_data()
 
     QTest::newRow("fully-readable") << 0444 << true;
     QTest::newRow("user-readable") << 0400 << true;
-    QTest::newRow("not-readable-by-us") << 0004 << false;
+    QTest::newRow("user-readable2") << 0440 << true;
+    QTest::newRow("not-readable-by-us") << 0044 << false;
+    QTest::newRow("not-readable-by-us2") << 0004 << false;
     QTest::newRow("not-readable-at-all") << 0000 << false;
 }
 
@@ -750,6 +833,72 @@ void KFileItemTest::testIsReadable()
 
     KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
     QCOMPARE(fileItem.isReadable(), readable);
+
+    QVERIFY(file.remove());
+    // still cached thanks to the cached internal udsentry
+    QCOMPARE(fileItem.isReadable(), readable);
+}
+
+void KFileItemTest::testIsWritable_data()
+{
+    QTest::addColumn<int>("mode");
+    QTest::addColumn<bool>("writable");
+
+    QTest::newRow("fully-writable") << 0333 << true;
+    QTest::newRow("user-writable") << 0300 << true;
+    QTest::newRow("user-writable2") << 0330 << true;
+    QTest::newRow("not-writable-by-us") << 0033 << false;
+    QTest::newRow("not-writable-by-us2") << 0003 << false;
+    QTest::newRow("not-writable-at-all") << 0000 << false;
+}
+
+void KFileItemTest::testIsWritable()
+{
+    QFETCH(int, mode);
+    QFETCH(bool, writable);
+
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    int ret = fchmod(file.handle(), (mode_t)mode);
+    QCOMPARE(ret, 0);
+
+    KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
+    QCOMPARE(fileItem.isWritable(), writable);
+
+    QVERIFY(file.remove());
+    // still cached thanks to the cached internal udsentry
+    QCOMPARE(fileItem.isWritable(), writable);
+}
+
+void KFileItemTest::testIsExecutable_data()
+{
+    QTest::addColumn<int>("mode");
+    QTest::addColumn<bool>("executable");
+
+    QTest::newRow("fully-executable") << 0111 << true;
+    QTest::newRow("user-executable") << 0100 << true;
+    QTest::newRow("user-executable2") << 0110 << true;
+    QTest::newRow("not-executable-by-us") << 0011 << false;
+    QTest::newRow("not-executable-by-us2") << 0001 << false;
+    QTest::newRow("not-executable-at-all") << 0000 << false;
+}
+
+void KFileItemTest::testIsExecutable()
+{
+    QFETCH(int, mode);
+    QFETCH(bool, executable);
+
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    int ret = fchmod(file.handle(), (mode_t)mode);
+    QCOMPARE(ret, 0);
+
+    KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
+    QCOMPARE(fileItem.isExecutable(), executable);
+
+    QVERIFY(file.remove());
+    // still cached thanks to the cached internal udsentry
+    QCOMPARE(fileItem.isExecutable(), executable);
 }
 
 // Restore permissions so that the QTemporaryDir cleanup can happen (taken from tst_qsavefile.cpp)
@@ -804,3 +953,5 @@ void KFileItemTest::testNonWritableDirectory()
 }
 
 #endif // Q_OS_WIN
+
+#include "moc_kfileitemtest.cpp"
