@@ -29,6 +29,7 @@ private Q_SLOTS:
     void testCmpByUrl();
     void testRename();
     void testRefresh();
+    void testExists();
     void testDotDirectory();
     void testMimetypeForRemoteFolder();
     void testMimetypeForRemoteFolderWithFileType();
@@ -40,6 +41,10 @@ private Q_SLOTS:
 #ifndef Q_OS_WIN
     void testIsReadable_data();
     void testIsReadable();
+    void testIsWritable_data();
+    void testIsWritable();
+    void testIsExecutable_data();
+    void testIsExecutable();
 #endif
 
     void testDecodeFileName_data();
