@@ -31,11 +31,17 @@
 QTEST_GUILESS_MAIN(OpenUrlJobTest)
 
 extern KSERVICE_EXPORT int ksycoca_ms_between_checks;
+extern bool openurljob_force_use_browserapp_kdeglobals; // From openurljob.cpp
 
 static const char s_tempServiceName[] = "openurljobtest_service.desktop";
 
 void OpenUrlJobTest::initTestCase()
 {
+#if defined(Q_OS_WIN32) || defined(Q_OS_MAC)
+    // Don't run on Windows or Mac, the test implementation is too XDG-centric
+    QSKIP("Test not useful on this platform");
+#endif
+
     QStandardPaths::setTestModeEnabled(true);
 
     // Ensure no leftovers from other tests
@@ -55,7 +61,7 @@ void OpenUrlJobTest::initTestCase()
 
     // Ensure our service is the preferred one
     KConfig mimeAppsCfg(mimeApps);
-    KConfigGroup grp = mimeAppsCfg.group("Default Applications");
+    KConfigGroup grp = mimeAppsCfg.group(QStringLiteral("Default Applications"));
     grp.writeEntry("text/plain", s_tempServiceName);
     grp.writeEntry("text/html", s_tempServiceName);
     grp.sync();
@@ -236,7 +242,7 @@ KCONFIGCORE_EXPORT void loadUrlActionRestrictions(const KConfigGroup &cg);
 
 void OpenUrlJobTest::notAuthorized()
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE URL Restrictions");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KDE URL Restrictions"));
     cg.writeEntry("rule_count", 1);
     cg.writeEntry("rule_1", QStringList{"open", {}, {}, {}, "file", "", "", "false"});
     cg.sync();
@@ -484,8 +490,10 @@ void OpenUrlJobTest::launchExternalBrowser()
 
     QUrl remoteImage("http://example.org/image.jpg");
     if (useBrowserApp) {
-        KConfigGroup(KSharedConfig::openConfig(), "General").writeEntry("BrowserApplication", QString(QLatin1Char('!') + scriptFile));
+        openurljob_force_use_browserapp_kdeglobals = true;
+        KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General")).writeEntry("BrowserApplication", QString(QLatin1Char('!') + scriptFile));
     } else if (useSchemeHandler) {
+        openurljob_force_use_browserapp_kdeglobals = false;
         remoteImage.setScheme("scheme");
     }
 
@@ -504,7 +512,7 @@ void OpenUrlJobTest::launchExternalBrowser()
     QCOMPARE(readFile(dest), remoteImage.toString());
 
     // Restore settings
-    KConfigGroup(KSharedConfig::openConfig(), "General").deleteEntry("BrowserApplication");
+    KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General")).deleteEntry("BrowserApplication");
 #endif
 }
 
@@ -521,13 +529,19 @@ void OpenUrlJobTest::httpUrlWithKIO()
     // This tests the scanFileWithGet() code path
     const QUrl url(QStringLiteral("http://www.google.com/"));
     KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, this);
+    job->setEnableExternalBrowser(false);
     job->setFollowRedirections(false);
     QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     // Then the service should be executed (which writes to "dest")
     const QString dest = m_tempDir.path() + "/dest";
     QTRY_VERIFY2(QFile::exists(dest), qPrintable(dest));
-    QCOMPARE(readFile(dest), url.toString());
+    QVERIFY(QFile::exists(dest));
+    auto resultfile = readFile(dest);
+    QVERIFY(QFile::exists(resultfile));
+    auto result = readFile(resultfile);
+    QVERIFY(result.startsWith(QStringLiteral("<!doctype html>")));
+    QVERIFY(result.endsWith(QStringLiteral("</html>")));
 }
 
 void OpenUrlJobTest::ftpUrlWithKIO()
@@ -580,3 +594,5 @@ void OpenUrlJobTest::writeApplicationDesktopFile(const QString &filePath, const
     group.writeEntry("Exec", command);
     QVERIFY(file.sync());
 }
+
+#include "moc_openurljobtest.cpp"
