@@ -103,9 +103,9 @@ bool ConnectionBackend::listenForRemote()
     static QBasicAtomicInt s_socketCounter = Q_BASIC_ATOMIC_INITIALIZER(1);
     QString appName = QCoreApplication::instance()->applicationName();
     appName.replace(QLatin1Char('/'), QLatin1Char('_')); // #357499
-    QTemporaryFile socketfile(prefix + QLatin1Char('/') + appName + QStringLiteral("XXXXXX.%1.slave-socket").arg(s_socketCounter.fetchAndAddAcquire(1)));
+    QTemporaryFile socketfile(prefix + QLatin1Char('/') + appName + QStringLiteral("XXXXXX.%1.kioworker.socket").arg(s_socketCounter.fetchAndAddAcquire(1)));
     if (!socketfile.open()) {
-        errorString = i18n("Unable to create io-slave: %1", QString::fromUtf8(strerror(errno)));
+        errorString = i18n("Unable to create KIO worker: %1", QString::fromUtf8(strerror(errno)));
         return false;
     }
 
@@ -172,11 +172,9 @@ bool ConnectionBackend::sendCommand(int cmd, const QByteArray &data) const
     Q_ASSERT(socket);
 
     char buffer[HeaderSize + 2];
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    // KF6 TODO: check if this breaks 32bit support,
+    // see https://invent.kde.org/frameworks/kio/-/merge_requests/1141#note_606633
     sprintf(buffer, "%6llx_%2x_", data.size(), cmd);
-#else
-    sprintf(buffer, "%6x_%2x_", data.size(), cmd);
-#endif
     socket->write(buffer, HeaderSize);
     socket->write(data);
 
@@ -286,3 +284,5 @@ void ConnectionBackend::socketReadyRead()
         }
     } while (shouldReadAnother);
 }
+
+#include "moc_connectionbackend_p.cpp"
