@@ -9,6 +9,7 @@
 #include "davjob.h"
 
 #include <QDataStream>
+#include <QDomDocument>
 
 #include "httpmethod_p.h"
 
@@ -28,9 +29,6 @@ public:
     }
     QByteArray savedStaticData;
     QByteArray str_response;
-    QDomDocument m_response;
-    // TransferJob *m_subJob;
-    // bool m_suspended;
 
     Q_DECLARE_PUBLIC(DavJob)
 
@@ -64,9 +62,9 @@ DavJob::DavJob(DavJobPrivate &dd, int method, const QString &request)
     }
 }
 
-QDomDocument &DavJob::response()
+QByteArray DavJob::responseData() const
 {
-    return d_func()->m_response;
+    return d_func()->str_response;
 }
 
 void DavJob::slotData(const QByteArray &data)
@@ -85,7 +83,8 @@ void DavJob::slotFinished()
     // qDebug() << d->str_response;
     if (!d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() && (d->m_command == CMD_SPECIAL)) {
         QDataStream istream(d->m_packedArgs);
-        int s_cmd, s_method;
+        int s_cmd;
+        int s_method;
         qint64 s_size;
         QUrl s_url;
         istream >> s_cmd;
@@ -98,33 +97,22 @@ void DavJob::slotFinished()
             QDataStream stream(&d->m_packedArgs, QIODevice::WriteOnly);
             stream << (int)7 << d->m_redirectionURL << (int)KIO::DAV_PROPFIND << s_size;
         }
-    } else if (!d->m_response.setContent(d->str_response, true)) {
-        // An error occurred parsing the XML response
-        QDomElement root = d->m_response.createElementNS(QStringLiteral("DAV:"), QStringLiteral("error-report"));
-        d->m_response.appendChild(root);
-
-        QDomElement el = d->m_response.createElementNS(QStringLiteral("DAV:"), QStringLiteral("offending-response"));
-        QDomText textnode = d->m_response.createTextNode(QString::fromUtf8(d->str_response));
-        el.appendChild(textnode);
-        root.appendChild(el);
     }
-    // qDebug() << d->m_response.toString();
     TransferJob::slotFinished();
     d->staticData = d->savedStaticData; // Need to send DAV request to this host too
 }
 
 /* Convenience methods */
-
-DavJob *KIO::davPropFind(const QUrl &url, const QDomDocument &properties, const QString &depth, JobFlags flags)
+DavJob *KIO::davPropFind(const QUrl &url, const QString &properties, const QString &depth, JobFlags flags)
 {
-    DavJob *job = DavJobPrivate::newJob(url, (int)KIO::DAV_PROPFIND, properties.toString(), flags);
+    DavJob *job = DavJobPrivate::newJob(url, (int)KIO::DAV_PROPFIND, properties, flags);
     job->addMetaData(QStringLiteral("davDepth"), depth);
     return job;
 }
 
-DavJob *KIO::davPropPatch(const QUrl &url, const QDomDocument &properties, JobFlags flags)
+DavJob *KIO::davPropPatch(const QUrl &url, const QString &properties, JobFlags flags)
 {
-    return DavJobPrivate::newJob(url, (int)KIO::DAV_PROPPATCH, properties.toString(), flags);
+    return DavJobPrivate::newJob(url, (int)KIO::DAV_PROPPATCH, properties, flags);
 }
 
 DavJob *KIO::davSearch(const QUrl &url, const QString &nsURI, const QString &qName, const QString &query, JobFlags flags)
@@ -145,3 +133,5 @@ DavJob *KIO::davReport(const QUrl &url, const QString &report, const QString &de
     job->addMetaData(QStringLiteral("davDepth"), depth);
     return job;
 }
+
+#include "moc_davjob.cpp"
