@@ -13,7 +13,6 @@
 
 namespace KIO
 {
-
 class FileJobPrivate;
 /**
  * @class KIO::FileJob filejob.h <KIO/FileJob>
@@ -21,7 +20,7 @@ class FileJobPrivate;
  *  The file-job is an asynchronous version of normal file handling.
  *  It allows block-wise reading and writing, and allows seeking and truncation. Results are returned through signals.
  *
- *  Should always be created using KIO::open(QUrl)
+ *  Should always be created using KIO::open(const QUrl&, QIODevice::OpenMode).
  */
 
 class KIOCORE_EXPORT FileJob : public SimpleJob
@@ -29,7 +28,7 @@ class KIOCORE_EXPORT FileJob : public SimpleJob
     Q_OBJECT
 
 public:
-    ~FileJob();
+    ~FileJob() override;
 
     /**
      * This function attempts to read up to \p size bytes from the URL passed to
@@ -67,16 +66,16 @@ public:
     void write(const QByteArray &data);
 
     /**
-     * Closes the file-slave
+     * Closes the file KIO worker.
      *
-     * The slave emits close() and result().
+     * The worker emits close() and result().
      */
     void close();
 
     /**
      * Seek
      *
-     * The slave emits position() on successful seek to the specified \p offset.
+     * The worker emits position() on successful seek to the specified \p offset.
      *
      * On error the position() signal is not emitted. To catch errors please
      * connect to the result() signal.
@@ -88,7 +87,7 @@ public:
     /**
      * Truncate
      *
-     * The slave emits truncated() on successful truncation to the specified \p length.
+     * The worker emits truncated() on successful truncation to the specified \p length.
      *
      * On error the truncated() signal is not emitted. To catch errors please
      * connect to the result() signal.
@@ -107,13 +106,13 @@ public:
 
 Q_SIGNALS:
     /**
-     * Data from the slave has arrived. Emitted after read().
+     * Data from the worker has arrived. Emitted after read().
      *
      * Unless a read() request was sent for 0 bytes, End of data (EOD) has been
      * reached if data.size() == 0
      *
      * @param job the job that emitted this signal
-     * @param data data received from the slave.
+     * @param data data received from the worker.
      *
      */
     void data(KIO::Job *job, const QByteArray &data);
@@ -126,17 +125,6 @@ Q_SIGNALS:
      */
     void redirection(KIO::Job *job, const QUrl &url);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 78)
-    /**
-     * MIME type determined.
-     * @param job the job that emitted this signal
-     * @param mimeType the MIME type
-     * @deprecated Since 5.78, use mimeTypeFound(KIO::Job *, const QString &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 78, "Use KIO::TransferJob::mimeTypeFound(KIO::Job *, const QString &)")
-    void mimetype(KIO::Job *job, const QString &mimeType);
-#endif
-
     /**
      * MIME type determined.
      * @param job the job that emitted this signal
@@ -147,7 +135,7 @@ Q_SIGNALS:
 
     /**
      * File is open, metadata has been determined and the
-     * file-slave is ready to receive commands.
+     * file KIO worker is ready to receive commands.
      * @param job the job that emitted this signal
      */
     void open(KIO::Job *job);
@@ -160,10 +148,13 @@ Q_SIGNALS:
     void written(KIO::Job *job, KIO::filesize_t written);
 
     /**
-     * File is closed and will accept no more commands
+     * Signals that the file is closed and will accept no more commands.
+     *
      * @param job the job that emitted this signal
+     *
+     * @since 5.79
      */
-    void close(KIO::Job *job);
+    void fileClosed(KIO::Job *job);
 
     /**
      * The file has reached this position. Emitted after seek().
@@ -181,19 +172,9 @@ Q_SIGNALS:
     void truncated(KIO::Job *job, KIO::filesize_t length);
 
 protected:
-    FileJob(FileJobPrivate &dd);
+    KIOCORE_NO_EXPORT explicit FileJob(FileJobPrivate &dd);
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void slotRedirection(const QUrl &))
-    Q_PRIVATE_SLOT(d_func(), void slotData(const QByteArray &data))
-    Q_PRIVATE_SLOT(d_func(), void slotMimetype(const QString &mimetype))
-    Q_PRIVATE_SLOT(d_func(), void slotOpen())
-    Q_PRIVATE_SLOT(d_func(), void slotWritten(KIO::filesize_t))
-    Q_PRIVATE_SLOT(d_func(), void slotFinished())
-    Q_PRIVATE_SLOT(d_func(), void slotPosition(KIO::filesize_t))
-    Q_PRIVATE_SLOT(d_func(), void slotTruncated(KIO::filesize_t))
-    Q_PRIVATE_SLOT(d_func(), void slotTotalSize(KIO::filesize_t))
-
     Q_DECLARE_PRIVATE(FileJob)
 };
 
