@@ -11,6 +11,7 @@
 
 #include "kprotocolmanager.h"
 #include "kprotocolinfo_p.h"
+#include "kprotocolmanager_p.h"
 
 #include "hostinfo.h"
 
@@ -51,12 +52,9 @@
 
 #include <kprotocolinfofactory_p.h>
 
-#include "http_worker_defaults.h"
 #include "ioworker_defaults.h"
 #include "workerconfig.h"
 
-using SubnetPair = QPair<QHostAddress, int>;
-
 /*
     Domain suffix match. E.g. return true if host is "cuzco.inka.de" and
     nplist is "inka.de,hadiko.de" or if host is "localhost" and nplist is
@@ -104,50 +102,6 @@ static bool revmatch(const char *host, const char *nplist)
     return false;
 }
 
-class KProxyData : public QObject
-{
-    Q_OBJECT
-public:
-    KProxyData(const QString &workerProtocol, const QStringList &proxyAddresses)
-        : protocol(workerProtocol)
-        , proxyList(proxyAddresses)
-    {
-    }
-
-    void removeAddress(const QString &address)
-    {
-        proxyList.removeAll(address);
-    }
-
-    QString protocol;
-    QStringList proxyList;
-};
-
-class KProtocolManagerPrivate
-{
-public:
-    KProtocolManagerPrivate();
-    ~KProtocolManagerPrivate();
-    bool shouldIgnoreProxyFor(const QUrl &url);
-    void sync();
-    KProtocolManager::ProxyType proxyType();
-    bool useReverseProxy();
-    QString readNoProxyFor();
-    QString proxyFor(const QString &protocol);
-    QStringList getSystemProxyFor(const QUrl &url);
-
-    QMutex mutex; // protects all member vars
-    KSharedConfig::Ptr configPtr;
-    KSharedConfig::Ptr http_config;
-    QString modifiers;
-    QString useragent;
-    QString noProxyFor;
-    QList<SubnetPair> noProxySubnets;
-    QCache<QString, KProxyData> cachedProxyData;
-
-    QMap<QString /*mimetype*/, QString /*protocol*/> protocolForArchiveMimetypes;
-};
-
 Q_GLOBAL_STATIC(KProtocolManagerPrivate, kProtocolManagerPrivate)
 
 static void syncOnExit()
@@ -174,9 +128,9 @@ KProtocolManagerPrivate::~KProtocolManagerPrivate()
 bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
 {
     bool isMatch = false;
-    const KProtocolManager::ProxyType type = proxyType();
-    const bool useRevProxy = ((type == KProtocolManager::ManualProxy) && useReverseProxy());
-    const bool useNoProxyList = (type == KProtocolManager::ManualProxy || type == KProtocolManager::EnvVarProxy);
+    const ProxyType type = proxyType();
+    const bool useRevProxy = ((type == ManualProxy) && useReverseProxy());
+    const bool useNoProxyList = (type == ManualProxy || type == EnvVarProxy);
 
     // No proxy only applies to ManualProxy and EnvVarProxy types...
     if (useNoProxyList && noProxyFor.isEmpty()) {
@@ -284,22 +238,22 @@ static KSharedConfig::Ptr config()
     return d->configPtr;
 }
 
-KProtocolManager::ProxyType KProtocolManagerPrivate::proxyType()
+KProtocolManagerPrivate::ProxyType KProtocolManagerPrivate::proxyType()
 {
-    KConfigGroup cg(config(), "Proxy Settings");
-    return static_cast<KProtocolManager::ProxyType>(cg.readEntry("ProxyType", 0));
+    KConfigGroup cg(config(), QStringLiteral("Proxy Settings"));
+    return static_cast<ProxyType>(cg.readEntry("ProxyType", 0));
 }
 
 bool KProtocolManagerPrivate::useReverseProxy()
 {
-    KConfigGroup cg(config(), "Proxy Settings");
+    KConfigGroup cg(config(), QStringLiteral("Proxy Settings"));
     return cg.readEntry("ReversedException", false);
 }
 
 QString KProtocolManagerPrivate::readNoProxyFor()
 {
-    QString noProxy = config()->group("Proxy Settings").readEntry("NoProxyFor");
-    if (proxyType() == KProtocolManager::EnvVarProxy) {
+    QString noProxy = config()->group(QStringLiteral("Proxy Settings")).readEntry("NoProxyFor");
+    if (proxyType() == EnvVarProxy) {
         noProxy = QString::fromLocal8Bit(qgetenv(noProxy.toLocal8Bit().constData()));
     }
     return noProxy;
@@ -312,16 +266,6 @@ QMap<QString, QString> KProtocolManager::entryMap(const QString &group)
     return config()->entryMap(group);
 }
 
-static KConfigGroup http_config()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    Q_ASSERT(!d->mutex.tryLock()); // the caller must have locked the mutex
-    if (!d->http_config) {
-        d->http_config = KSharedConfig::openConfig(QStringLiteral("kio_httprc"), KConfig::NoGlobals);
-    }
-    return KConfigGroup(d->http_config, QString());
-}
-
 /*=============================== TIMEOUT SETTINGS ==========================*/
 
 int KProtocolManager::readTimeout()
@@ -360,83 +304,6 @@ int KProtocolManager::responseTimeout()
     return qMax(MIN_TIMEOUT_VALUE, val);
 }
 
-/*========================== PROXY SETTINGS =================================*/
-
-bool KProtocolManager::useProxy()
-{
-    return proxyType() != NoProxy;
-}
-
-bool KProtocolManager::useReverseProxy()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return d->useReverseProxy();
-}
-
-KProtocolManager::ProxyType KProtocolManager::proxyType()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return d->proxyType();
-}
-
-KProtocolManager::ProxyAuthMode KProtocolManager::proxyAuthMode()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    KConfigGroup cg(config(), "Proxy Settings");
-    return static_cast<ProxyAuthMode>(cg.readEntry("AuthMode", 0));
-}
-
-/*========================== CACHING =====================================*/
-
-bool KProtocolManager::useCache()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return http_config().readEntry("UseCache", true);
-}
-
-KIO::CacheControl KProtocolManager::cacheControl()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    QString tmp = http_config().readEntry("cache");
-    if (tmp.isEmpty()) {
-        return DEFAULT_CACHE_CONTROL;
-    }
-    return KIO::parseCacheControl(tmp);
-}
-
-QString KProtocolManager::cacheDir()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return http_config().readPathEntry("CacheDir", QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/kio_http"));
-}
-
-int KProtocolManager::maxCacheAge()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return http_config().readEntry("MaxCacheAge", DEFAULT_MAX_CACHE_AGE);
-}
-
-int KProtocolManager::maxCacheSize()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return http_config().readEntry("MaxCacheSize", DEFAULT_MAX_CACHE_SIZE);
-}
-
-QString KProtocolManager::noProxyFor()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return d->readNoProxyFor();
-}
-
 static QString adjustProtocol(const QString &scheme)
 {
     if (scheme.compare(QLatin1String("webdav"), Qt::CaseInsensitive) == 0) {
@@ -450,17 +317,10 @@ static QString adjustProtocol(const QString &scheme)
     return scheme.toLower();
 }
 
-QString KProtocolManager::proxyFor(const QString &protocol)
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return d->proxyFor(protocol);
-}
-
 QString KProtocolManagerPrivate::proxyFor(const QString &protocol)
 {
     const QString key = adjustProtocol(protocol) + QLatin1String("Proxy");
-    QString proxyStr(config()->group("Proxy Settings").readEntry(key));
+    QString proxyStr(config()->group(QStringLiteral("Proxy Settings")).readEntry(key));
     const int index = proxyStr.lastIndexOf(QLatin1Char(' '));
 
     if (index > -1) {
@@ -479,17 +339,6 @@ QString KProtocolManagerPrivate::proxyFor(const QString &protocol)
     return proxyStr;
 }
 
-QString KProtocolManager::proxyForUrl(const QUrl &url)
-{
-    const QStringList proxies = proxiesForUrl(url);
-
-    if (proxies.isEmpty()) {
-        return QString();
-    }
-
-    return proxies.first();
-}
-
 QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
 {
     QStringList proxies;
@@ -545,7 +394,7 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
     return proxies;
 }
 
-QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
+QStringList KProtocolManagerPrivate::proxiesForUrl(const QUrl &url)
 {
     QStringList proxyList;
 
@@ -562,7 +411,7 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
 #ifndef KIO_ANDROID_STUB
             if (protocol.startsWith(QLatin1String("http")) || protocol.startsWith(QLatin1String("ftp"))) {
                 QDBusReply<QStringList> reply =
-                    QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout"), QStringLiteral("org.kde.KPAC.ProxyScout"))
+                    QDBusInterface(QStringLiteral("org.kde.kded6"), QStringLiteral("/modules/proxyscout"), QStringLiteral("org.kde.KPAC.ProxyScout"))
                         .call(QStringLiteral("proxiesForUrl"), u.toString());
                 proxyList = reply;
             }
@@ -600,36 +449,6 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
     return proxyList;
 }
 
-void KProtocolManager::badProxy(const QString &proxy)
-{
-#ifndef KIO_ANDROID_STUB
-    QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout")).asyncCall(QStringLiteral("blackListProxy"), proxy);
-#endif
-
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    const QStringList keys(d->cachedProxyData.keys());
-    for (const QString &key : keys) {
-        d->cachedProxyData[key]->removeAddress(proxy);
-    }
-}
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-QString KProtocolManager::slaveProtocol(const QUrl &url, QString &proxy)
-{
-    return workerProtocol(url, proxy);
-}
-#endif
-
-QString KProtocolManager::workerProtocol(const QUrl &url, QString &proxy)
-{
-    QStringList proxyList;
-    const QString protocol = KProtocolManager::workerProtocol(url, proxyList);
-    if (!proxyList.isEmpty()) {
-        proxy = proxyList.first();
-    }
-    return protocol;
-}
-
 // Generates proxy cache key from request given url.
 static QString extractProxyCacheKeyFromUrl(const QUrl &u)
 {
@@ -642,29 +461,20 @@ static QString extractProxyCacheKeyFromUrl(const QUrl &u)
     return key;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-QString KProtocolManager::slaveProtocol(const QUrl &url, QStringList &proxyList)
-{
-    return workerProtocol(url, proxyList);
-}
-#endif
-
-QString KProtocolManager::workerProtocol(const QUrl &url, QStringList &proxyList)
+QString KProtocolManagerPrivate::workerProtocol(const QUrl &url, QStringList &proxyList)
 {
     proxyList.clear();
-
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
+    QMutexLocker lock(&d->mutex);
     // Do not perform a proxy lookup for any url classified as a ":local" url or
     // one that does not have a host component or if proxy is disabled.
     QString protocol(url.scheme());
-    if (url.host().isEmpty() || KProtocolInfo::protocolClass(protocol) == QLatin1String(":local")
-        || KProtocolManager::proxyType() == KProtocolManager::NoProxy) {
+    if (url.host().isEmpty() || KProtocolInfo::protocolClass(protocol) == QLatin1String(":local") || kProtocolManagerPrivate->proxyType() == NoProxy) {
         return protocol;
     }
 
     const QString proxyCacheKey = extractProxyCacheKeyFromUrl(url);
 
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
     // Look for cached proxy information to avoid more work.
     if (d->cachedProxyData.contains(proxyCacheKey)) {
         KProxyData *data = d->cachedProxyData.object(proxyCacheKey);
@@ -673,7 +483,7 @@ QString KProtocolManager::workerProtocol(const QUrl &url, QStringList &proxyList
     }
     lock.unlock();
 
-    const QStringList proxies = proxiesForUrl(url);
+    const QStringList proxies = KProtocolManagerPrivate::proxiesForUrl(url);
     const int count = proxies.count();
 
     if (count > 0 && !(count == 1 && proxies.first() == QLatin1String("DIRECT"))) {
@@ -713,30 +523,6 @@ QString KProtocolManager::workerProtocol(const QUrl &url, QStringList &proxyList
 
 /*================================= USER-AGENT SETTINGS =====================*/
 
-QString KProtocolManager::userAgentForHost(const QString &hostname)
-{
-    const QString sendUserAgent = KIO::WorkerConfig::self()->configData(QStringLiteral("http"), hostname.toLower(), QStringLiteral("SendUserAgent")).toLower();
-    if (sendUserAgent == QLatin1String("false")) {
-        return QString();
-    }
-
-    const QString useragent = KIO::WorkerConfig::self()->configData(QStringLiteral("http"), hostname.toLower(), QStringLiteral("UserAgent"));
-
-    // Return the default user-agent if none is specified
-    // for the requested host.
-    if (useragent.isEmpty()) {
-        return defaultUserAgent();
-    }
-
-    return useragent;
-}
-
-QString KProtocolManager::defaultUserAgent()
-{
-    const QString modifiers = KIO::WorkerConfig::self()->configData(QStringLiteral("http"), QString(), QStringLiteral("UserAgentKeys"));
-    return defaultUserAgent(modifiers);
-}
-
 // This is not the OS, but the windowing system, e.g. X11 on Unix/Linux.
 static QString platform()
 {
@@ -751,13 +537,13 @@ static QString platform()
 #endif
 }
 
-QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
+QString KProtocolManagerPrivate::defaultUserAgent(const QString &_modifiers)
 {
     KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     QString modifiers = _modifiers.toLower();
     if (modifiers.isEmpty()) {
-        modifiers = QString::fromLatin1(DEFAULT_USER_AGENT_KEYS);
+        modifiers = QStringLiteral("om"); // Show OS, Machine
     }
 
     if (d->modifiers == modifiers && !d->useragent.isEmpty()) {
@@ -770,7 +556,7 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
     QString systemVersion;
     QString machine;
     QString supp;
-    const bool sysInfoFound = getSystemNameVersionAndMachine(systemName, systemVersion, machine);
+    const bool sysInfoFound = KProtocolManagerPrivate::getSystemNameVersionAndMachine(systemName, systemVersion, machine);
 
     supp += platform();
 
@@ -808,31 +594,9 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
     return d->useragent;
 }
 
-QString KProtocolManager::userAgentForApplication(const QString &appName, const QString &appVersion, const QStringList &extraInfo)
+bool KProtocolManagerPrivate::getSystemNameVersionAndMachine(QString &systemName, QString &systemVersion, QString &machine)
 {
-    QString systemName;
-    QString systemVersion;
-    QString machine;
-    QString info;
-
-    if (getSystemNameVersionAndMachine(systemName, systemVersion, machine)) {
-        info += systemName + QLatin1Char('/') + systemVersion + QLatin1String("; ");
-    }
-
-    info += QLatin1String("KDE/") + QStringLiteral(KIO_VERSION_STRING);
-
-    if (!machine.isEmpty()) {
-        info += QLatin1String("; ") + machine;
-    }
-
-    info += QLatin1String("; ") + extraInfo.join(QLatin1String("; "));
-
-    return (appName + QLatin1Char('/') + appVersion + QStringLiteral(" (") + info + QLatin1Char(')'));
-}
-
-bool KProtocolManager::getSystemNameVersionAndMachine(QString &systemName, QString &systemVersion, QString &machine)
-{
-#if defined(Q_OS_WIN) && !defined(_WIN32_WCE)
+#if defined(Q_OS_WIN)
     // we do not use unameBuf.sysname information constructed in kdewin32
     // because we want to get separate name and version
     systemName = QStringLiteral("Windows");
@@ -862,113 +626,28 @@ bool KProtocolManager::getSystemNameVersionAndMachine(QString &systemName, QStri
     return true;
 }
 
-QString KProtocolManager::acceptLanguagesHeader()
-{
-    const QLatin1String english("en");
-
-    // User's desktop language preference.
-    QStringList languageList = QLocale().uiLanguages();
-
-    // Replace possible "C" in the language list with "en", unless "en" is
-    // already present. This is to keep user's priorities in order.
-    // If afterwards "en" is still not present, append it.
-    int idx = languageList.indexOf(QLatin1String("C"));
-    if (idx != -1) {
-        if (languageList.contains(english)) {
-            languageList.removeAt(idx);
-        } else {
-            languageList[idx] = english;
-        }
-    }
-    if (!languageList.contains(english)) {
-        languageList += english;
-    }
-
-    // Some languages may have web codes different from locale codes,
-    // read them from the config and insert in proper order.
-    KConfig acclangConf(QStringLiteral("accept-languages.codes"), KConfig::NoGlobals);
-    KConfigGroup replacementCodes(&acclangConf, "ReplacementCodes");
-    QStringList languageListFinal;
-    for (const QString &lang : std::as_const(languageList)) {
-        const QStringList langs = replacementCodes.readEntry(lang, QStringList());
-        if (langs.isEmpty()) {
-            languageListFinal += lang;
-        } else {
-            languageListFinal += langs;
-        }
-    }
-
-    // The header is composed of comma separated languages, with an optional
-    // associated priority estimate (q=1..0) defaulting to 1.
-    // As our language tags are already sorted by priority, we'll just decrease
-    // the value evenly
-    int prio = 10;
-    QString header;
-    for (const QString &lang : std::as_const(languageListFinal)) {
-        header += lang;
-        if (prio < 10) {
-            header += QLatin1String(";q=0.") + QString::number(prio);
-        }
-        // do not add cosmetic whitespace in here : it is less compatible (#220677)
-        header += QLatin1Char(',');
-        if (prio > 1) {
-            --prio;
-        }
-    }
-    header.chop(1);
-
-    // Some of the languages may have country specifier delimited by
-    // underscore, or modifier delimited by at-sign.
-    // The header should use dashes instead.
-    header.replace(QLatin1Char('_'), QLatin1Char('-'));
-    header.replace(QLatin1Char('@'), QLatin1Char('-'));
-
-    return header;
-}
-
 /*==================================== OTHERS ===============================*/
 
 bool KProtocolManager::markPartial()
 {
     KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
-    return config()->group(QByteArray()).readEntry("MarkPartial", true);
+    return config()->group(QString()).readEntry("MarkPartial", true);
 }
 
 int KProtocolManager::minimumKeepSize()
 {
     KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
-    return config()->group(QByteArray()).readEntry("MinimumKeepSize",
-                                                   DEFAULT_MINIMUM_KEEP_SIZE); // 5000 byte
+    return config()->group(QString()).readEntry("MinimumKeepSize",
+                                                DEFAULT_MINIMUM_KEEP_SIZE); // 5000 byte
 }
 
 bool KProtocolManager::autoResume()
 {
     KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
-    return config()->group(QByteArray()).readEntry("AutoResume", false);
-}
-
-bool KProtocolManager::persistentConnections()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return config()->group(QByteArray()).readEntry("PersistentConnections", true);
-}
-
-bool KProtocolManager::persistentProxyConnection()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return config()->group(QByteArray()).readEntry("PersistentProxyConnection", false);
-}
-
-QString KProtocolManager::proxyConfigScript()
-{
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
-    QMutexLocker lock(&d->mutex);
-    return config()->group("Proxy Settings").readEntry("Proxy Config Script");
+    return config()->group(QString()).readEntry("AutoResume", false);
 }
 
 /* =========================== PROTOCOL CAPABILITIES ============== */
@@ -980,8 +659,8 @@ static KProtocolInfoPrivate *findProtocol(const QUrl &url)
     }
     QString protocol = url.scheme();
     if (!KProtocolInfo::proxiedBy(protocol).isEmpty()) {
-        QString dummy;
-        protocol = KProtocolManager::workerProtocol(url, dummy);
+        QStringList dummy;
+        protocol = KProtocolManagerPrivate::workerProtocol(url, dummy);
     }
 
     return KProtocolInfoFactory::self()->findProtocol(protocol);
@@ -1220,4 +899,4 @@ bool KProtocolManager::supportsPermissions(const QUrl &url)
 
 #undef PRIVATE_DATA
 
-#include "kprotocolmanager.moc"
+#include "moc_kprotocolmanager_p.cpp"
