@@ -13,6 +13,8 @@
 #include "ksambasharedata.h"
 #include "ksambasharedata_p.h"
 
+#include "../utils_p.h"
+
 #include <QDebug>
 #include <QFile>
 #include <QFileInfo>
@@ -31,16 +33,6 @@
 Q_DECLARE_LOGGING_CATEGORY(KIO_CORE_SAMBASHARE)
 Q_LOGGING_CATEGORY(KIO_CORE_SAMBASHARE, "kf.kio.core.sambashare", QtWarningMsg)
 
-// Default smb.conf locations
-// sorted by priority, most priority first
-static const char *const DefaultSambaConfigFilePathList[] = {"/etc/samba/smb.conf",
-                                                             "/etc/smb.conf",
-                                                             "/usr/local/etc/smb.conf",
-                                                             "/usr/local/samba/lib/smb.conf",
-                                                             "/usr/samba/lib/smb.conf",
-                                                             "/usr/lib/smb.conf",
-                                                             "/usr/local/lib/smb.conf"};
-
 KSambaSharePrivate::KSambaSharePrivate(KSambaShare *parent)
     : q_ptr(parent)
     , data()
@@ -48,9 +40,6 @@ KSambaSharePrivate::KSambaSharePrivate(KSambaShare *parent)
     , skipUserShare(false)
 {
     setUserSharePath();
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
-    findSmbConf();
-#endif
     data = parse(getNetUserShareInfo());
 }
 
@@ -74,25 +63,6 @@ bool KSambaSharePrivate::isSambaInstalled()
     return daemonExists && clientExists;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
-// Try to find the samba config file path
-// in several well-known paths
-bool KSambaSharePrivate::findSmbConf()
-{
-    for (const char *str : DefaultSambaConfigFilePathList) {
-        const QString filePath = QString::fromLatin1(str);
-        if (QFile::exists(filePath)) {
-            smbConf = filePath;
-            return true;
-        }
-    }
-
-    qCDebug(KIO_CORE_SAMBASHARE) << "KSambaShare: Could not find smb.conf!";
-
-    return false;
-}
-#endif
-
 void KSambaSharePrivate::setUserSharePath()
 {
     const QString rawString = testparmParamValue(QStringLiteral("usershare path"));
@@ -315,7 +285,8 @@ KSambaShareData::UserShareError KSambaSharePrivate::isAclValid(const QString &ac
 {
     // NOTE: capital D is not missing from the regex net usershare will in fact refuse to consider it valid
     //   - verified 2020-08-20
-    const QRegularExpression aclRx(QRegularExpression::anchoredPattern(QStringLiteral("(?:(?:(\\w(\\w|\\s)*)\\\\|)(\\w+\\s*):([fFrRd]{1})(?:,|))*")));
+    static const auto pattern = uR"--((?:(?:(\w(\w|\s)*)\\|)(\w+\s*):([fFrRd]{1})(?:,|))*)--";
+    static const QRegularExpression aclRx(QRegularExpression::anchoredPattern(pattern));
     // TODO: check if user is a valid smb user
     return aclRx.match(acl).hasMatch() ? KSambaShareData::UserShareAclOk : KSambaShareData::UserShareAclInvalid;
 }
@@ -417,15 +388,11 @@ KSambaShareData::UserShareError KSambaSharePrivate::remove(const KSambaShareData
 
 QMap<QString, KSambaShareData> KSambaSharePrivate::parse(const QByteArray &usershareData)
 {
-    const QRegularExpression headerRx(
-        QRegularExpression::anchoredPattern(QStringLiteral("^\\s*\\["
-                                                           "([^%<>*\?|/+=;:\",]+)"
-                                                           "\\]")));
+    static const char16_t headerPattern[] = uR"--(^\s*\[([^%<>*?|/+=;:",]+)\])--";
+    static const QRegularExpression headerRx(QRegularExpression::anchoredPattern(headerPattern));
 
-    const QRegularExpression OptValRx(
-        QRegularExpression::anchoredPattern(QStringLiteral("^\\s*([\\w\\d\\s]+)"
-                                                           "="
-                                                           "(.*)$")));
+    static const char16_t valPattern[] = uR"--(^\s*([\w\d\s]+)=(.*)$)--";
+    static const QRegularExpression OptValRx(QRegularExpression::anchoredPattern(valPattern));
 
     QTextStream stream(usershareData);
     QString currentShare;
@@ -451,7 +418,7 @@ QMap<QString, KSambaShareData> KSambaSharePrivate::parse(const QByteArray &users
             if (key == QLatin1String("path")) {
                 // Samba accepts paths with and w/o trailing slash, we
                 // use and expect path without slash
-                shareData.dd->path = value.endsWith(QLatin1Char('/')) ? value.chopped(1) : value;
+                shareData.dd->path = Utils::trailingSlashRemoved(value);
             } else if (key == QLatin1String("comment")) {
                 shareData.dd->comment = value;
             } else if (key == QLatin1String("usershare_acl")) {
@@ -472,7 +439,7 @@ QMap<QString, KSambaShareData> KSambaSharePrivate::parse(const QByteArray &users
     return shares;
 }
 
-void KSambaSharePrivate::_k_slotFileChange(const QString &path)
+void KSambaSharePrivate::slotFileChange(const QString &path)
 {
     if (path != userSharePath) {
         return;
@@ -487,12 +454,11 @@ KSambaShare::KSambaShare()
     : QObject(nullptr)
     , d_ptr(new KSambaSharePrivate(this))
 {
-    Q_D(const KSambaShare);
+    Q_D(KSambaShare);
     if (!d->userSharePath.isEmpty() && QFileInfo::exists(d->userSharePath)) {
         KDirWatch::self()->addDir(d->userSharePath, KDirWatch::WatchFiles);
-        connect(KDirWatch::self(), &KDirWatch::dirty, this, [this](const QString &path) {
-            Q_D(KSambaShare);
-            d->_k_slotFileChange(path);
+        connect(KDirWatch::self(), &KDirWatch::dirty, this, [d](const QString &path) {
+            d->slotFileChange(path);
         });
     }
 }
@@ -506,14 +472,6 @@ KSambaShare::~KSambaShare()
     delete d_ptr;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
-QString KSambaShare::smbConfPath() const
-{
-    Q_D(const KSambaShare);
-    return d->smbConf;
-}
-#endif
-
 bool KSambaShare::isDirectoryShared(const QString &path) const
 {
     Q_D(const KSambaShare);
