@@ -85,13 +85,11 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
     void slotFinished() override;
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101) // override no longer needed
-    void slotMetaData(const KIO::MetaData &_metaData) override;
-#endif
     void slotResult(KJob *job) override;
 
 protected:
-    ListJob(ListJobPrivate &dd);
+    KIOCORE_NO_EXPORT explicit ListJob(ListJobPrivate &dd);
+
     Q_DECLARE_PRIVATE(ListJob)
     friend class ListJobPrivate;
 };
