@@ -12,8 +12,9 @@
 
 #include "connection_p.h"
 #include "job_p.h"
+#include "kprotocolmanager_p.h"
 #include "sessiondata_p.h"
-#include "slave.h"
+#include "worker_p.h"
 #include "workerconfig.h"
 
 #include <kprotocolinfo.h>
@@ -27,14 +28,14 @@
 #include <QThread>
 #include <QThreadStorage>
 
-// Slaves may be idle for a certain time (3 minutes) before they are killed.
-static const int s_idleSlaveLifetime = 3 * 60;
+// Workers may be idle for a certain time (3 minutes) before they are killed.
+static const int s_idleWorkerLifetime = 3 * 60;
 
 using namespace KIO;
 
-static inline Slave *jobSlave(SimpleJob *job)
+static inline Worker *jobSWorker(SimpleJob *job)
 {
-    return SimpleJobPrivate::get(job)->m_slave;
+    return SimpleJobPrivate::get(job)->m_worker;
 }
 
 static inline int jobCommand(SimpleJob *job)
@@ -42,9 +43,9 @@ static inline int jobCommand(SimpleJob *job)
     return SimpleJobPrivate::get(job)->m_command;
 }
 
-static inline void startJob(SimpleJob *job, Slave *slave)
+static inline void startJob(SimpleJob *job, Worker *worker)
 {
-    SimpleJobPrivate::get(job)->start(slave);
+    SimpleJobPrivate::get(job)->start(worker);
 }
 
 class KIO::SchedulerPrivate
@@ -57,10 +58,10 @@ public:
 
     ~SchedulerPrivate()
     {
-        removeSlaveOnHold();
+        removeWorkerOnHold();
         delete q;
         q = nullptr;
-        qDeleteAll(m_protocols); // ~ProtoQueue will kill and delete all slaves
+        qDeleteAll(m_protocols); // ~ProtoQueue will kill and delete all workers
     }
 
     SchedulerPrivate(const SchedulerPrivate &) = delete;
@@ -68,45 +69,36 @@ public:
 
     Scheduler *q;
 
-    Slave *m_slaveOnHold = nullptr;
+    Worker *m_workerOnHold = nullptr;
     QUrl m_urlOnHold;
     bool m_ignoreConfigReparse = false;
 
     SessionData sessionData;
 
     void doJob(SimpleJob *job);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
-    void scheduleJob(SimpleJob *job);
-#endif
     void setJobPriority(SimpleJob *job, int priority);
     void cancelJob(SimpleJob *job);
-    void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
-    void putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url);
-    void removeSlaveOnHold();
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-    Slave *getConnectedSlave(const QUrl &url, const KIO::MetaData &metaData);
-    bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
-    bool disconnectSlave(KIO::Slave *slave);
-#endif
-    Slave *heldSlaveForJob(KIO::SimpleJob *job);
-    bool isSlaveOnHoldFor(const QUrl &url);
+    void jobFinished(KIO::SimpleJob *job, KIO::Worker *worker);
+    void putWorkerOnHold(KIO::SimpleJob *job, const QUrl &url);
+    void removeWorkerOnHold();
+    Worker *heldWorkerForJob(KIO::SimpleJob *job);
+    bool isWorkerOnHoldFor(const QUrl &url);
     void updateInternalMetaData(SimpleJob *job);
 
     MetaData metaDataFor(const QString &protocol, const QStringList &proxyList, const QUrl &url);
-    void
-    setupSlave(KIO::Slave *slave, const QUrl &url, const QString &protocol, const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = nullptr);
+    void setupWorker(KIO::Worker *worker,
+                     const QUrl &url,
+                     const QString &protocol,
+                     const QStringList &proxyList,
+                     bool newWorker,
+                     const KIO::MetaData *config = nullptr);
 
-    void slotSlaveDied(KIO::Slave *slave);
+    void slotWorkerDied(KIO::Worker *worker);
 
 #ifndef KIO_ANDROID_STUB
     void slotReparseSlaveConfiguration(const QString &, const QDBusMessage &);
 #endif
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-    void slotSlaveConnected();
-    void slotSlaveError(int error, const QString &errorMsg);
-#endif
-
     ProtoQueue *protoQ(const QString &protocol, const QString &host);
 
 private:
@@ -148,94 +140,94 @@ int SerialPicker::changedPrioritySerial(int oldSerial, int newPriority) const
     return unbiasedSerial + newPriority * m_jobsPerPriority;
 }
 
-SlaveKeeper::SlaveKeeper()
+WorkerManager::WorkerManager()
 {
     m_grimTimer.setSingleShot(true);
-    connect(&m_grimTimer, &QTimer::timeout, this, &SlaveKeeper::grimReaper);
+    connect(&m_grimTimer, &QTimer::timeout, this, &WorkerManager::grimReaper);
 }
 
-SlaveKeeper::~SlaveKeeper()
+WorkerManager::~WorkerManager()
 {
     grimReaper();
 }
 
-void SlaveKeeper::returnSlave(Slave *slave)
+void WorkerManager::returnWorker(Worker *worker)
 {
-    Q_ASSERT(slave);
-    slave->setIdle();
-    m_idleSlaves.insert(slave->host(), slave);
+    Q_ASSERT(worker);
+    worker->setIdle();
+    m_idleWorkers.insert(worker->host(), worker);
     scheduleGrimReaper();
 }
 
-Slave *SlaveKeeper::takeSlaveForJob(SimpleJob *job)
+Worker *WorkerManager::takeWorkerForJob(SimpleJob *job)
 {
-    Slave *slave = schedulerPrivate()->heldSlaveForJob(job);
-    if (slave) {
-        return slave;
+    Worker *worker = schedulerPrivate()->heldWorkerForJob(job);
+    if (worker) {
+        return worker;
     }
 
     QUrl url = SimpleJobPrivate::get(job)->m_url;
     // TODO take port, username and password into account
-    QMultiHash<QString, Slave *>::Iterator it = m_idleSlaves.find(url.host());
-    if (it == m_idleSlaves.end()) {
-        it = m_idleSlaves.begin();
+    QMultiHash<QString, Worker *>::Iterator it = m_idleWorkers.find(url.host());
+    if (it == m_idleWorkers.end()) {
+        it = m_idleWorkers.begin();
     }
-    if (it == m_idleSlaves.end()) {
+    if (it == m_idleWorkers.end()) {
         return nullptr;
     }
-    slave = it.value();
-    m_idleSlaves.erase(it);
-    return slave;
+    worker = it.value();
+    m_idleWorkers.erase(it);
+    return worker;
 }
 
-bool SlaveKeeper::removeSlave(Slave *slave)
+bool WorkerManager::removeWorker(Worker *worker)
 {
     // ### performance not so great
-    QMultiHash<QString, Slave *>::Iterator it = m_idleSlaves.begin();
-    for (; it != m_idleSlaves.end(); ++it) {
-        if (it.value() == slave) {
-            m_idleSlaves.erase(it);
+    QMultiHash<QString, Worker *>::Iterator it = m_idleWorkers.begin();
+    for (; it != m_idleWorkers.end(); ++it) {
+        if (it.value() == worker) {
+            m_idleWorkers.erase(it);
             return true;
         }
     }
     return false;
 }
 
-void SlaveKeeper::clear()
+void WorkerManager::clear()
 {
-    m_idleSlaves.clear();
+    m_idleWorkers.clear();
 }
 
-QList<Slave *> SlaveKeeper::allSlaves() const
+QList<Worker *> WorkerManager::allWorkers() const
 {
-    return m_idleSlaves.values();
+    return m_idleWorkers.values();
 }
 
-void SlaveKeeper::scheduleGrimReaper()
+void WorkerManager::scheduleGrimReaper()
 {
     if (!m_grimTimer.isActive()) {
-        m_grimTimer.start((s_idleSlaveLifetime / 2) * 1000);
+        m_grimTimer.start((s_idleWorkerLifetime / 2) * 1000);
     }
 }
 
 // private slot
-void SlaveKeeper::grimReaper()
+void WorkerManager::grimReaper()
 {
-    QMultiHash<QString, Slave *>::Iterator it = m_idleSlaves.begin();
-    while (it != m_idleSlaves.end()) {
-        Slave *slave = it.value();
-        if (slave->idleTime() >= s_idleSlaveLifetime) {
-            it = m_idleSlaves.erase(it);
-            if (slave->job()) {
-                // qDebug() << "Idle slave" << slave << "still has job" << slave->job();
+    QMultiHash<QString, Worker *>::Iterator it = m_idleWorkers.begin();
+    while (it != m_idleWorkers.end()) {
+        Worker *worker = it.value();
+        if (worker->idleTime() >= s_idleWorkerLifetime) {
+            it = m_idleWorkers.erase(it);
+            if (worker->job()) {
+                // qDebug() << "Idle worker" << worker << "still has job" << worker->job();
             }
-            // avoid invoking slotSlaveDied() because its cleanup services are not needed
-            slave->kill();
+            // avoid invoking slotWorkerDied() because its cleanup services are not needed
+            worker->kill();
         } else {
             ++it;
         }
     }
-    if (!m_idleSlaves.isEmpty()) {
+    if (!m_idleWorkers.isEmpty()) {
         scheduleGrimReaper();
     }
 }
@@ -281,159 +273,18 @@ bool HostQueue::removeJob(SimpleJob *job)
     return false;
 }
 
-QList<Slave *> HostQueue::allSlaves() const
+QList<Worker *> HostQueue::allWorkers() const
 {
-    QList<Slave *> ret;
+    QList<Worker *> ret;
     ret.reserve(m_runningJobs.size());
     for (SimpleJob *job : m_runningJobs) {
-        Slave *slave = jobSlave(job);
-        Q_ASSERT(slave);
-        ret.append(slave);
+        Worker *worker = jobSWorker(job);
+        Q_ASSERT(worker);
+        ret.append(worker);
     }
     return ret;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-ConnectedSlaveQueue::ConnectedSlaveQueue()
-{
-    m_startJobsTimer.setSingleShot(true);
-    connect(&m_startJobsTimer, &QTimer::timeout, this, &ConnectedSlaveQueue::startRunnableJobs);
-}
-
-bool ConnectedSlaveQueue::queueJob(SimpleJob *job, Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    SimpleJobPrivate::get(job)->m_slave = slave;
-
-    PerSlaveQueue &jobs = it.value();
-    jobs.waitingList.append(job);
-    if (!jobs.runningJob) {
-        // idle slave now has a job to run
-        m_runnableSlaves.insert(slave);
-        m_startJobsTimer.start();
-    }
-    return true;
-}
-
-bool ConnectedSlaveQueue::removeJob(SimpleJob *job)
-{
-    Slave *slave = jobSlave(job);
-    Q_ASSERT(slave);
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    PerSlaveQueue &jobs = it.value();
-    if (jobs.runningJob || jobs.waitingList.isEmpty()) {
-        // a slave that was busy running a job was not runnable.
-        // a slave that has no waiting job(s) was not runnable either.
-        Q_ASSERT(!m_runnableSlaves.contains(slave));
-    }
-
-    const bool removedRunning = jobs.runningJob == job;
-    const bool removedWaiting = jobs.waitingList.removeAll(job) != 0;
-    if (removedRunning) {
-        jobs.runningJob = nullptr;
-        Q_ASSERT(!removedWaiting);
-    }
-    const bool removedTheJob = removedRunning || removedWaiting;
-
-    if (!slave->isAlive()) {
-        removeSlave(slave);
-        return removedTheJob;
-    }
-
-    if (removedRunning && jobs.waitingList.count()) {
-        m_runnableSlaves.insert(slave);
-        m_startJobsTimer.start();
-    }
-    if (removedWaiting && jobs.waitingList.isEmpty()) {
-        m_runnableSlaves.remove(slave);
-    }
-    return removedTheJob;
-}
-
-void ConnectedSlaveQueue::addSlave(Slave *slave)
-{
-    Q_ASSERT(slave);
-    if (!m_connectedSlaves.contains(slave)) {
-        m_connectedSlaves.insert(slave, PerSlaveQueue());
-    }
-}
-
-bool ConnectedSlaveQueue::removeSlave(Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    PerSlaveQueue &jobs = it.value();
-    // we need a copy as kill() ends up removing the job from waitingList
-    const QList<SimpleJob *> waitingJobs = jobs.waitingList;
-    for (SimpleJob *job : waitingJobs) {
-        // ### for compatibility with the old scheduler we don't touch the running job, if any.
-        // make sure that the job doesn't call back into Scheduler::cancelJob(); this would
-        // a) crash and b) be unnecessary because we clean up just fine.
-        SimpleJobPrivate::get(job)->m_schedSerial = 0;
-        job->kill();
-    }
-    m_connectedSlaves.erase(it);
-    m_runnableSlaves.remove(slave);
-
-    slave->kill();
-    return true;
-}
-
-// KDE5: only one caller, for doubtful reasons. remove this if possible.
-bool ConnectedSlaveQueue::isIdle(Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    return it.value().runningJob == nullptr;
-}
-
-// private slot
-void ConnectedSlaveQueue::startRunnableJobs()
-{
-    QSet<Slave *>::Iterator it = m_runnableSlaves.begin();
-    while (it != m_runnableSlaves.end()) {
-        Slave *slave = *it;
-        if (!slave->isConnected()) {
-            // this polling is somewhat inefficient...
-            m_startJobsTimer.start();
-            ++it;
-            continue;
-        }
-        it = m_runnableSlaves.erase(it);
-        PerSlaveQueue &jobs = m_connectedSlaves[slave];
-        SimpleJob *job = jobs.waitingList.takeFirst();
-        Q_ASSERT(!jobs.runningJob);
-        jobs.runningJob = job;
-
-        const QUrl url = job->url();
-        // no port is -1 in QUrl, but in kde3 we used 0 and the KIO workers assume that.
-        const int port = url.port() == -1 ? 0 : url.port();
-
-        if (slave->host() == QLatin1String("<reset>")) {
-            MetaData configData = WorkerConfig::self()->configData(url.scheme(), url.host());
-            slave->setConfig(configData);
-            slave->setProtocol(url.scheme());
-            slave->setHost(url.host(), port, url.userName(), url.password());
-        }
-
-        Q_ASSERT(slave->protocol() == url.scheme());
-        Q_ASSERT(slave->host() == url.host());
-        Q_ASSERT(slave->port() == port);
-        startJob(job, slave);
-    }
-}
-#endif
-
 static void ensureNoDuplicates(QMap<int, HostQueue *> *queuesBySerial)
 {
     Q_UNUSED(queuesBySerial);
@@ -488,13 +339,13 @@ ProtoQueue::ProtoQueue(int maxWorkers, int maxWorkersPerHost)
 
 ProtoQueue::~ProtoQueue()
 {
-    // Gather list of all slaves first
-    const QList<Slave *> slaves = allSlaves();
-    // Clear the idle slaves in the keeper to avoid dangling pointers
-    m_slaveKeeper.clear();
-    for (Slave *slave : slaves) {
-        // kill the slave process and remove the interface in our process
-        slave->kill();
+    // Gather list of all workers first
+    const QList<Worker *> workers = allWorkers();
+    // Clear the idle workers in the manager to avoid dangling pointers
+    m_workerManager.clear();
+    for (Worker *worker : workers) {
+        // kill the worker process and remove the interface in our process
+        worker->kill();
     }
 }
 
@@ -572,7 +423,7 @@ void ProtoQueue::removeJob(SimpleJob *job)
     if (hq.removeJob(job)) {
         if (hq.lowestSerial() != prevLowestSerial) {
             // we have dequeued the not yet running job with the lowest serial
-            Q_ASSERT(!jobPriv->m_slave);
+            Q_ASSERT(!jobPriv->m_worker);
             Q_ASSERT(prevRunningJobs == hq.runningJobsCount());
             if (m_queuesBySerial.remove(prevLowestSerial) == 0) {
                 // make sure that the queue was not scheduled for a good reason
@@ -596,33 +447,24 @@ void ProtoQueue::removeJob(SimpleJob *job)
             m_queuesByHostname.remove(jobPriv->m_url.host());
         }
 
-        if (jobPriv->m_slave && jobPriv->m_slave->isAlive()) {
-            m_slaveKeeper.returnSlave(jobPriv->m_slave);
+        if (jobPriv->m_worker && jobPriv->m_worker->isAlive()) {
+            m_workerManager.returnWorker(jobPriv->m_worker);
         }
         // just in case; startAJob() will refuse to start a job if it shouldn't.
         m_startJobTimer.start();
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-    } else {
-        // should be a connected slave
-        // if the assertion fails the job has probably changed the host part of its URL while
-        // running, so we can't find it by hostname. don't do this.
-        const bool removed = m_connectedSlaveQueue.removeJob(job);
-        Q_UNUSED(removed);
-        Q_ASSERT(removed);
-#endif
     }
 
     ensureNoDuplicates(&m_queuesBySerial);
 }
 
-Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const QUrl &url)
+Worker *ProtoQueue::createWorker(const QString &protocol, SimpleJob *job, const QUrl &url)
 {
     int error;
     QString errortext;
-    Slave *slave = Slave::createSlave(protocol, url, error, errortext);
-    if (slave) {
-        connect(slave, &Slave::slaveDied, scheduler(), [](KIO::Slave *slave) {
-            schedulerPrivate()->slotSlaveDied(slave);
+    Worker *worker = Worker::createWorker(protocol, url, error, errortext);
+    if (worker) {
+        connect(worker, &Worker::workerDied, scheduler(), [](KIO::Worker *worker) {
+            schedulerPrivate()->slotWorkerDied(worker);
         });
     } else {
         qCWarning(KIO_CORE) << "couldn't create worker:" << errortext;
@@ -630,32 +472,23 @@ Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const QU
             job->slotError(error, errortext);
         }
     }
-    return slave;
+    return worker;
 }
 
-bool ProtoQueue::removeSlave(KIO::Slave *slave)
+bool ProtoQueue::removeWorker(KIO::Worker *worker)
 {
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-    const bool removedConnected = m_connectedSlaveQueue.removeSlave(slave);
-    const bool removedUnconnected = m_slaveKeeper.removeSlave(slave);
-    Q_ASSERT(!(removedConnected && removedUnconnected));
-    return removedConnected || removedUnconnected;
-#else
-    const bool removed = m_slaveKeeper.removeSlave(slave);
+    const bool removed = m_workerManager.removeWorker(worker);
     return removed;
-#endif
 }
 
-QList<Slave *> ProtoQueue::allSlaves() const
+QList<Worker *> ProtoQueue::allWorkers() const
 {
-    QList<Slave *> ret(m_slaveKeeper.allSlaves());
+    QList<Worker *> ret(m_workerManager.allWorkers());
     auto it = m_queuesByHostname.cbegin();
     for (; it != m_queuesByHostname.cend(); ++it) {
-        ret.append(it.value().allSlaves());
+        ret.append(it.value().allWorkers());
     }
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-    ret.append(m_connectedSlaveQueue.allSlaves());
-#endif
+
     return ret;
 }
 
@@ -703,25 +536,25 @@ void ProtoQueue::startAJob()
             m_queuesBySerial.insert(hq->lowestSerial(), hq);
         }
 
-        // always increase m_runningJobsCount because it's correct if there is a slave and if there
-        // is no slave, removeJob() will balance the number again. removeJob() would decrease the
+        // always increase m_runningJobsCount because it's correct if there is a worker and if there
+        // is no worker, removeJob() will balance the number again. removeJob() would decrease the
         // number too much otherwise.
-        // Note that createSlave() can call slotError() on a job which in turn calls removeJob(),
+        // Note that createWorker() can call slotError() on a job which in turn calls removeJob(),
         // so increase the count here already.
         m_runningJobsCount++;
 
-        bool isNewSlave = false;
-        Slave *slave = m_slaveKeeper.takeSlaveForJob(startingJob);
+        bool isNewWorker = false;
+        Worker *worker = m_workerManager.takeWorkerForJob(startingJob);
         SimpleJobPrivate *jobPriv = SimpleJobPrivate::get(startingJob);
-        if (!slave) {
-            isNewSlave = true;
-            slave = createSlave(jobPriv->m_protocol, startingJob, jobPriv->m_url);
+        if (!worker) {
+            isNewWorker = true;
+            worker = createWorker(jobPriv->m_protocol, startingJob, jobPriv->m_url);
         }
 
-        if (slave) {
-            jobPriv->m_slave = slave;
-            schedulerPrivate()->setupSlave(slave, jobPriv->m_url, jobPriv->m_protocol, jobPriv->m_proxyList, isNewSlave);
-            startJob(startingJob, slave);
+        if (worker) {
+            jobPriv->m_worker = worker;
+            schedulerPrivate()->setupWorker(worker, jobPriv->m_url, jobPriv->m_protocol, jobPriv->m_proxyList, isNewWorker);
+            startJob(startingJob, worker);
         } else {
             // dispose of our records about the job and mark the job as unknown
             // (to prevent crashes later)
@@ -772,76 +605,30 @@ void Scheduler::doJob(SimpleJob *job)
     schedulerPrivate()->doJob(job);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
-void Scheduler::scheduleJob(SimpleJob *job)
-{
-    schedulerPrivate()->scheduleJob(job);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 90)
-void Scheduler::setJobPriority(SimpleJob *job, int priority)
-{
-    schedulerPrivate()->setJobPriority(job, priority);
-}
-#endif
-
 // static
-void Scheduler::setSimpleJobPriority(SimpleJob *job, int priority)
-{
-    schedulerPrivate()->setJobPriority(job, priority);
-}
-
 void Scheduler::cancelJob(SimpleJob *job)
 {
     schedulerPrivate()->cancelJob(job);
 }
 
-void Scheduler::jobFinished(KIO::SimpleJob *job, KIO::Slave *slave)
+void Scheduler::jobFinished(KIO::SimpleJob *job, KIO::Worker *worker)
 {
-    schedulerPrivate()->jobFinished(job, slave);
+    schedulerPrivate()->jobFinished(job, worker);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-void Scheduler::putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url)
-{
-    schedulerPrivate()->putSlaveOnHold(job, url);
-}
-#endif
-
 void Scheduler::putWorkerOnHold(KIO::SimpleJob *job, const QUrl &url)
 {
-    schedulerPrivate()->putSlaveOnHold(job, url);
+    schedulerPrivate()->putWorkerOnHold(job, url);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-void Scheduler::removeSlaveOnHold()
-{
-    schedulerPrivate()->removeSlaveOnHold();
-}
-#endif
-
 void Scheduler::removeWorkerOnHold()
 {
-    schedulerPrivate()->removeSlaveOnHold();
+    schedulerPrivate()->removeWorkerOnHold();
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 88)
-void Scheduler::publishSlaveOnHold()
-{
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-bool Scheduler::isSlaveOnHoldFor(const QUrl &url)
-{
-    return schedulerPrivate()->isSlaveOnHoldFor(url);
-}
-#endif
-
 bool Scheduler::isWorkerOnHoldFor(const QUrl &url)
 {
-    return schedulerPrivate()->isSlaveOnHoldFor(url);
+    return schedulerPrivate()->isWorkerOnHoldFor(url);
 }
 
 void Scheduler::updateInternalMetaData(SimpleJob *job)
@@ -849,57 +636,6 @@ void Scheduler::updateInternalMetaData(SimpleJob *job)
     schedulerPrivate()->updateInternalMetaData(job);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-KIO::Slave *Scheduler::getConnectedSlave(const QUrl &url, const KIO::MetaData &config)
-{
-    return schedulerPrivate()->getConnectedSlave(url, config);
-}
-
-bool Scheduler::assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job)
-{
-    return schedulerPrivate()->assignJobToSlave(slave, job);
-}
-
-bool Scheduler::disconnectSlave(KIO::Slave *slave)
-{
-    return schedulerPrivate()->disconnectSlave(slave);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
-bool Scheduler::connect(const char *signal, const QObject *receiver, const char *member)
-{
-    return QObject::connect(self(), signal, receiver, member);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
-bool Scheduler::connect(const QObject *sender, const char *signal, const QObject *receiver, const char *member)
-{
-    return QObject::connect(sender, signal, receiver, member);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
-bool Scheduler::disconnect(const QObject *sender, const char *signal, const QObject *receiver, const char *member)
-{
-    return QObject::disconnect(sender, signal, receiver, member);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
-bool Scheduler::connect(const QObject *sender, const char *signal, const char *member)
-{
-    return QObject::connect(sender, signal, member);
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 88)
-void Scheduler::checkSlaveOnHold(bool)
-{
-}
-#endif
-
 void Scheduler::emitReparseSlaveConfiguration()
 {
 #ifndef KIO_ANDROID_STUB
@@ -925,7 +661,6 @@ void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto, const
     KProtocolManager::reparseConfiguration();
     WorkerConfig::self()->reset();
     sessionData.reset();
-    NetRC::self()->reload();
 
     QHash<QString, ProtoQueue *>::ConstIterator it = proto.isEmpty() ? m_protocols.constBegin() : m_protocols.constFind(proto);
     QHash<QString, ProtoQueue *>::ConstIterator endIt = m_protocols.constEnd();
@@ -941,10 +676,10 @@ void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto, const
     }
 
     for (; it != endIt; ++it) {
-        const QList<KIO::Slave *> list = it.value()->allSlaves();
-        for (Slave *slave : list) {
-            slave->send(CMD_REPARSECONFIGURATION);
-            slave->resetHost();
+        const QList<KIO::Worker *> list = it.value()->allWorkers();
+        for (Worker *worker : list) {
+            worker->send(CMD_REPARSECONFIGURATION);
+            worker->resetHost();
         }
     }
 }
@@ -955,20 +690,12 @@ void SchedulerPrivate::doJob(SimpleJob *job)
     // qDebug() << job;
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
     jobPriv->m_proxyList.clear();
-    jobPriv->m_protocol = KProtocolManager::workerProtocol(job->url(), jobPriv->m_proxyList);
+    jobPriv->m_protocol = KProtocolManagerPrivate::workerProtocol(job->url(), jobPriv->m_proxyList);
 
     ProtoQueue *proto = protoQ(jobPriv->m_protocol, job->url().host());
     proto->queueJob(job);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
-void SchedulerPrivate::scheduleJob(SimpleJob *job)
-{
-    // qDebug() << job;
-    setJobPriority(job, 1);
-}
-#endif
-
 void SchedulerPrivate::setJobPriority(SimpleJob *job, int priority)
 {
     // qDebug() << job << priority;
@@ -988,21 +715,21 @@ void SchedulerPrivate::cancelJob(SimpleJob *job)
         // qDebug() << "Doing nothing because I don't know job" << job;
         return;
     }
-    Slave *slave = jobSlave(job);
-    // qDebug() << job << slave;
-    jobFinished(job, slave);
-    if (slave) {
+    Worker *worker = jobSWorker(job);
+    // qDebug() << job << worker;
+    jobFinished(job, worker);
+    if (worker) {
         ProtoQueue *pq = m_protocols.value(jobPriv->m_protocol);
         if (pq) {
-            pq->removeSlave(slave);
+            pq->removeWorker(worker);
         }
-        slave->kill(); // don't use slave after this!
+        worker->kill(); // don't use worker after this!
     }
 }
 
-void SchedulerPrivate::jobFinished(SimpleJob *job, Slave *slave)
+void SchedulerPrivate::jobFinished(SimpleJob *job, Worker *worker)
 {
-    // qDebug() << job << slave;
+    // qDebug() << job << worker;
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
 
     // make sure that we knew about the job!
@@ -1013,28 +740,28 @@ void SchedulerPrivate::jobFinished(SimpleJob *job, Slave *slave)
         pq->removeJob(job);
     }
 
-    if (slave) {
+    if (worker) {
         // If we have internal meta-data, tell existing KIO workers to reload
         // their configuration.
         if (jobPriv->m_internalMetaData.count()) {
             // qDebug() << "Updating KIO workers with new internal metadata information";
-            ProtoQueue *queue = m_protocols.value(slave->protocol());
+            ProtoQueue *queue = m_protocols.value(worker->protocol());
             if (queue) {
-                const QList<Slave *> slaves = queue->allSlaves();
-                for (auto *runningSlave : slaves) {
-                    if (slave->host() == runningSlave->host()) {
-                        slave->setConfig(metaDataFor(slave->protocol(), jobPriv->m_proxyList, job->url()));
-                        /*qDebug() << "Updated configuration of" << slave->protocol()
-                                     << "KIO worker, pid=" << slave->slave_pid();*/
+                const QList<Worker *> workers = queue->allWorkers();
+                for (auto *runningWorker : workers) {
+                    if (worker->host() == runningWorker->host()) {
+                        worker->setConfig(metaDataFor(worker->protocol(), jobPriv->m_proxyList, job->url()));
+                        /*qDebug() << "Updated configuration of" << worker->protocol()
+                                     << "KIO worker, pid=" << worker->worker_pid();*/
                     }
                 }
             }
         }
-        slave->setJob(nullptr);
-        slave->disconnect(job);
+        worker->setJob(nullptr);
+        worker->disconnect(job);
     }
     jobPriv->m_schedSerial = 0; // this marks the job as unscheduled again
-    jobPriv->m_slave = nullptr;
+    jobPriv->m_worker = nullptr;
     // Clear the values in the internal metadata container since they have
     // already been taken care of above...
     jobPriv->m_internalMetaData.clear();
@@ -1053,34 +780,15 @@ MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QStringLis
         configData[QStringLiteral("ProxyUrls")] = proxyList.join(QLatin1Char(','));
     }
 
-    if (configData.contains(QLatin1String("EnableAutoLogin"))
-        && configData.value(QStringLiteral("EnableAutoLogin")).compare(QLatin1String("true"), Qt::CaseInsensitive) == 0) {
-        NetRC::AutoLogin l;
-        l.login = url.userName();
-        bool usern = (protocol == QLatin1String("ftp"));
-        if (NetRC::self()->lookup(url, l, usern)) {
-            configData[QStringLiteral("autoLoginUser")] = l.login;
-            configData[QStringLiteral("autoLoginPass")] = l.password;
-            if (usern) {
-                QString macdef;
-                QMap<QString, QStringList>::ConstIterator it = l.macdef.constBegin();
-                for (; it != l.macdef.constEnd(); ++it) {
-                    macdef += it.key() + QLatin1Char('\\') + it.value().join(QLatin1Char('\\')) + QLatin1Char('\n');
-                }
-                configData[QStringLiteral("autoLoginMacro")] = macdef;
-            }
-        }
-    }
-
     return configData;
 }
 
-void SchedulerPrivate::setupSlave(KIO::Slave *slave,
-                                  const QUrl &url,
-                                  const QString &protocol,
-                                  const QStringList &proxyList,
-                                  bool newSlave,
-                                  const KIO::MetaData *config)
+void SchedulerPrivate::setupWorker(KIO::Worker *worker,
+                                   const QUrl &url,
+                                   const QString &protocol,
+                                   const QStringList &proxyList,
+                                   bool newWorker,
+                                   const KIO::MetaData *config)
 {
     int port = url.port();
     if (port == -1) { // no port is -1 in QUrl, but in kde3 we used 0 and the KIO workers assume that.
@@ -1090,59 +798,59 @@ void SchedulerPrivate::setupSlave(KIO::Slave *slave,
     const QString user = url.userName();
     const QString passwd = url.password();
 
-    if (newSlave || slave->host() != host || slave->port() != port || slave->user() != user || slave->passwd() != passwd) {
+    if (newWorker || worker->host() != host || worker->port() != port || worker->user() != user || worker->passwd() != passwd) {
         MetaData configData = metaDataFor(protocol, proxyList, url);
         if (config) {
             configData += *config;
         }
 
-        slave->setConfig(configData);
-        slave->setProtocol(url.scheme());
-        slave->setHost(host, port, user, passwd);
+        worker->setConfig(configData);
+        worker->setProtocol(url.scheme());
+        worker->setHost(host, port, user, passwd);
     }
 }
 
-void SchedulerPrivate::slotSlaveDied(KIO::Slave *slave)
+void SchedulerPrivate::slotWorkerDied(KIO::Worker *worker)
 {
-    // qDebug() << slave;
-    Q_ASSERT(slave);
-    Q_ASSERT(!slave->isAlive());
-    ProtoQueue *pq = m_protocols.value(slave->protocol());
+    // qDebug() << worker;
+    Q_ASSERT(worker);
+    Q_ASSERT(!worker->isAlive());
+    ProtoQueue *pq = m_protocols.value(worker->protocol());
     if (pq) {
-        if (slave->job()) {
-            pq->removeJob(slave->job());
+        if (worker->job()) {
+            pq->removeJob(worker->job());
         }
-        // in case this was a connected slave...
-        pq->removeSlave(slave);
+        // in case this was a connected worker...
+        pq->removeWorker(worker);
     }
-    if (slave == m_slaveOnHold) {
-        m_slaveOnHold = nullptr;
+    if (worker == m_workerOnHold) {
+        m_workerOnHold = nullptr;
         m_urlOnHold.clear();
     }
-    // can't use slave->deref() here because we need to use deleteLater
-    slave->aboutToDelete();
-    slave->deleteLater();
+    // can't use worker->deref() here because we need to use deleteLater
+    worker->aboutToDelete();
+    worker->deleteLater();
 }
 
-void SchedulerPrivate::putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url)
+void SchedulerPrivate::putWorkerOnHold(KIO::SimpleJob *job, const QUrl &url)
 {
-    Slave *slave = jobSlave(job);
-    // qDebug() << job << url << slave;
-    slave->disconnect(job);
-    // prevent the fake death of the slave from trying to kill the job again;
-    // cf. Slave::hold(const QUrl &url) called in SchedulerPrivate::publishSlaveOnHold().
-    slave->setJob(nullptr);
-    SimpleJobPrivate::get(job)->m_slave = nullptr;
+    Worker *worker = jobSWorker(job);
+    // qDebug() << job << url << worker;
+    worker->disconnect(job);
+    // prevent the fake death of the worker from trying to kill the job again;
+    // cf. Worker::hold(const QUrl &url) called in SchedulerPrivate::publishWorkerOnHold().
+    worker->setJob(nullptr);
+    SimpleJobPrivate::get(job)->m_worker = nullptr;
 
-    if (m_slaveOnHold) {
-        m_slaveOnHold->kill();
+    if (m_workerOnHold) {
+        m_workerOnHold->kill();
     }
-    m_slaveOnHold = slave;
+    m_workerOnHold = worker;
     m_urlOnHold = url;
-    m_slaveOnHold->suspend();
+    m_workerOnHold->suspend();
 }
 
-bool SchedulerPrivate::isSlaveOnHoldFor(const QUrl &url)
+bool SchedulerPrivate::isWorkerOnHoldFor(const QUrl &url)
 {
     if (url.isValid() && m_urlOnHold.isValid() && url == m_urlOnHold) {
         return true;
@@ -1151,15 +859,15 @@ bool SchedulerPrivate::isSlaveOnHoldFor(const QUrl &url)
     return false;
 }
 
-Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
+Worker *SchedulerPrivate::heldWorkerForJob(SimpleJob *job)
 {
-    Slave *slave = nullptr;
+    Worker *worker = nullptr;
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
 
-    if (m_slaveOnHold) {
+    if (m_workerOnHold) {
         // Make sure that the job wants to do a GET or a POST, and with no offset
         const int cmd = jobPriv->m_command;
-        bool canJobReuse = (cmd == CMD_GET || cmd == CMD_MULTI_GET);
+        bool canJobReuse = (cmd == CMD_GET);
 
         if (KIO::TransferJob *tJob = qobject_cast<KIO::TransferJob *>(job)) {
             canJobReuse = (canJobReuse || cmd == CMD_SPECIAL);
@@ -1174,72 +882,30 @@ Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
 
         if (job->url() == m_urlOnHold) {
             if (canJobReuse) {
-                // qDebug() << "HOLD: Reusing held slave (" << m_slaveOnHold << ")";
-                slave = m_slaveOnHold;
+                // qDebug() << "HOLD: Reusing held worker (" << m_workerOnHold << ")";
+                worker = m_workerOnHold;
             } else {
-                // qDebug() << "HOLD: Discarding held slave (" << m_slaveOnHold << ")";
-                m_slaveOnHold->kill();
+                // qDebug() << "HOLD: Discarding held worker (" << m_workerOnHold << ")";
+                m_workerOnHold->kill();
             }
-            m_slaveOnHold = nullptr;
+            m_workerOnHold = nullptr;
             m_urlOnHold.clear();
         }
     }
 
-    return slave;
+    return worker;
 }
 
-void SchedulerPrivate::removeSlaveOnHold()
+void SchedulerPrivate::removeWorkerOnHold()
 {
-    // qDebug() << m_slaveOnHold;
-    if (m_slaveOnHold) {
-        m_slaveOnHold->kill();
+    // qDebug() << m_workerOnHold;
+    if (m_workerOnHold) {
+        m_workerOnHold->kill();
     }
-    m_slaveOnHold = nullptr;
+    m_workerOnHold = nullptr;
     m_urlOnHold.clear();
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-Slave *SchedulerPrivate::getConnectedSlave(const QUrl &url, const KIO::MetaData &config)
-{
-    QStringList proxyList;
-    const QString protocol = KProtocolManager::workerProtocol(url, proxyList);
-    ProtoQueue *pq = protoQ(protocol, url.host());
-
-    Slave *slave = pq->createSlave(protocol, /* job */ nullptr, url);
-    if (slave) {
-        setupSlave(slave, url, protocol, proxyList, true, &config);
-        pq->m_connectedSlaveQueue.addSlave(slave);
-
-        slave->send(CMD_CONNECT);
-        q->connect(slave, SIGNAL(connected()), SLOT(slotSlaveConnected()));
-        q->connect(slave, SIGNAL(error(int, QString)), SLOT(slotSlaveError(int, QString)));
-    }
-    // qDebug() << url << slave;
-    return slave;
-}
-
-void SchedulerPrivate::slotSlaveConnected()
-{
-    // qDebug();
-    Slave *slave = static_cast<Slave *>(q->sender());
-    slave->setConnected(true);
-    q->disconnect(slave, SIGNAL(connected()), q, SLOT(slotSlaveConnected()));
-    Q_EMIT q->slaveConnected(slave);
-}
-
-void SchedulerPrivate::slotSlaveError(int errorNr, const QString &errorMsg)
-{
-    Slave *slave = static_cast<Slave *>(q->sender());
-    // qDebug() << slave << errorNr << errorMsg;
-    ProtoQueue *pq = protoQ(slave->protocol(), slave->host());
-    if (!slave->isConnected() || pq->m_connectedSlaveQueue.isIdle(slave)) {
-        // Only forward to application if slave is idle or still connecting.
-        // ### KDE5: can we remove this apparently arbitrary behavior and just always emit SlaveError?
-        Q_EMIT q->slaveError(slave, errorNr, errorMsg);
-    }
-}
-#endif
-
 ProtoQueue *SchedulerPrivate::protoQ(const QString &protocol, const QString &host)
 {
     ProtoQueue *pq = m_protocols.value(protocol, nullptr);
@@ -1265,27 +931,6 @@ ProtoQueue *SchedulerPrivate::protoQ(const QString &protocol, const QString &hos
     return pq;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
-bool SchedulerPrivate::assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
-{
-    // qDebug() << slave << job;
-    // KDE5: queueing of jobs can probably be removed, it provides very little benefit
-    ProtoQueue *pq = m_protocols.value(slave->protocol());
-    if (pq) {
-        pq->removeJob(job);
-        return pq->m_connectedSlaveQueue.queueJob(job, slave);
-    }
-    return false;
-}
-
-bool SchedulerPrivate::disconnectSlave(KIO::Slave *slave)
-{
-    // qDebug() << slave;
-    ProtoQueue *pq = m_protocols.value(slave->protocol());
-    return (pq ? pq->m_connectedSlaveQueue.removeSlave(slave) : false);
-}
-#endif
-
 void SchedulerPrivate::updateInternalMetaData(SimpleJob *job)
 {
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
