@@ -8,13 +8,13 @@
 
 #include "transferjob.h"
 #include "job_p.h"
-#include "slave.h"
-#include <kurlauthorized.h>
+#include "worker_p.h"
 #include <QDebug>
+#include <kurlauthorized.h>
 
 using namespace KIO;
 
-static const int MAX_READ_BUF_SIZE = (64 * 1024);       // 64 KB at a time seems reasonable...
+static const int MAX_READ_BUF_SIZE = (64 * 1024); // 64 KB at a time seems reasonable...
 
 TransferJob::TransferJob(TransferJobPrivate &dd)
     : SimpleJob(dd)
@@ -25,29 +25,28 @@ TransferJob::TransferJob(TransferJobPrivate &dd)
     }
 
     if (d->m_outgoingDataSource) {
-        connect(d->m_outgoingDataSource, SIGNAL(readChannelFinished()),
-                SLOT(slotIODeviceClosedBeforeStart()));
+        d->m_readChannelFinishedConnection = connect(d->m_outgoingDataSource, &QIODevice::readChannelFinished, this, [d]() {
+            d->slotIODeviceClosedBeforeStart();
+        });
     }
-
 }
 
 TransferJob::~TransferJob()
 {
 }
 
-// Slave sends data
+// Worker sends data
 void TransferJob::slotData(const QByteArray &_data)
 {
     Q_D(TransferJob);
     if (d->m_command == CMD_GET && !d->m_isMimetypeEmitted) {
-        qCWarning(KIO_CORE) << "mimeType() not emitted when sending first data!; job URL ="
-                   << d->m_url << "data size =" << _data.size();
+        qCWarning(KIO_CORE) << "mimeType() not emitted when sending first data!; job URL =" << d->m_url << "data size =" << _data.size();
     }
     // shut up the warning, HACK: downside is that it changes the meaning of the variable
     d->m_isMimetypeEmitted = true;
 
     if (d->m_redirectionURL.isEmpty() || !d->m_redirectionURL.isValid() || error()) {
-        emit data(this, _data);
+        Q_EMIT data(this, _data);
     }
 }
 
@@ -56,11 +55,11 @@ void KIO::TransferJob::setTotalSize(KIO::filesize_t bytes)
     setTotalAmount(KJob::Bytes, bytes);
 }
 
-// Slave got a redirection request
+// Worker got a redirection request
 void TransferJob::slotRedirection(const QUrl &url)
 {
     Q_D(TransferJob);
-    //qDebug() << url;
+    // qDebug() << url;
     if (!KUrlAuthorized::authorizeUrlAction(QStringLiteral("redirect"), d->m_url, url)) {
         qCWarning(KIO_CORE) << "Redirection from" << d->m_url << "to" << url << "REJECTED!";
         return;
@@ -70,7 +69,7 @@ void TransferJob::slotRedirection(const QUrl &url)
     // acts as the stage in a state-machine. We define "endless redirections"
     // as 5 redirections to the same URL.
     if (d->m_redirectionList.count(url) > 5) {
-        //qDebug() << "CYCLIC REDIRECTION!";
+        // qDebug() << "CYCLIC REDIRECTION!";
         setError(ERR_CYCLIC_LINK);
         setErrorText(d->m_url.toDisplayString());
     } else {
@@ -83,7 +82,7 @@ void TransferJob::slotRedirection(const QUrl &url)
             addMetaData(QStringLiteral("ssl_was_in_use"), QStringLiteral("FALSE"));
         }
         // Tell the user that we haven't finished yet
-        emit redirection(this, d->m_redirectionURL);
+        Q_EMIT redirection(this, d->m_redirectionURL);
     }
 }
 
@@ -91,17 +90,15 @@ void TransferJob::slotFinished()
 {
     Q_D(TransferJob);
 
-    //qDebug() << d->m_url;
+    // qDebug() << d->m_url;
     if (!d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid()) {
-
-        //qDebug() << "Redirection to" << m_redirectionURL;
+        // qDebug() << "Redirection to" << m_redirectionURL;
         if (queryMetaData(QStringLiteral("permanent-redirect")) == QLatin1String("true")) {
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
+            Q_EMIT permanentRedirection(this, d->m_url, d->m_redirectionURL);
         }
 
         if (queryMetaData(QStringLiteral("redirect-to-get")) == QLatin1String("true")) {
             d->m_command = CMD_GET;
-            d->m_outgoingMetaData.remove(QStringLiteral("CustomHTTPMethod"));
             d->m_outgoingMetaData.remove(QStringLiteral("content-type"));
         }
 
@@ -130,7 +127,8 @@ void TransferJob::slotFinished()
             }
             case CMD_PUT: {
                 int permissions;
-                qint8 iOverwrite, iResume;
+                qint8 iOverwrite;
+                qint8 iResume;
                 istream >> dummyUrl >> iOverwrite >> iResume >> permissions;
                 d->m_packedArgs.truncate(0);
                 QDataStream stream(&d->m_packedArgs, QIODevice::WriteOnly);
@@ -169,15 +167,15 @@ void TransferJob::setAsyncDataEnabled(bool enabled)
     }
 }
 
-void TransferJob::sendAsyncData(const QByteArray &dataForSlave)
+void TransferJob::sendAsyncData(const QByteArray &dataForWorker)
 {
     Q_D(TransferJob);
     if (d->m_extraFlags & JobPrivate::EF_TransferJobNeedData) {
-        if (d->m_slave) {
-            d->m_slave->send(MSG_DATA, dataForSlave);
+        if (d->m_worker) {
+            d->m_worker->send(MSG_DATA, dataForWorker);
         }
         if (d->m_extraFlags & JobPrivate::EF_TransferJobDataSent) { // put job -> emit progress
-            KIO::filesize_t size = processedAmount(KJob::Bytes) + dataForSlave.size();
+            KIO::filesize_t size = processedAmount(KJob::Bytes) + dataForWorker.size();
             setProcessedAmount(KJob::Bytes, size);
         }
     }
@@ -185,25 +183,6 @@ void TransferJob::sendAsyncData(const QByteArray &dataForSlave)
     d->m_extraFlags &= ~JobPrivate::EF_TransferJobNeedData;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 3)
-void TransferJob::setReportDataSent(bool enabled)
-{
-    Q_D(TransferJob);
-    if (enabled) {
-        d->m_extraFlags |= JobPrivate::EF_TransferJobDataSent;
-    } else {
-        d->m_extraFlags &= ~JobPrivate::EF_TransferJobDataSent;
-    }
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 3)
-bool TransferJob::reportDataSent() const
-{
-    return (d_func()->m_extraFlags & JobPrivate::EF_TransferJobDataSent);
-}
-#endif
-
 QString TransferJob::mimetype() const
 {
     return d_func()->m_mimetype;
@@ -214,19 +193,19 @@ QUrl TransferJob::redirectUrl() const
     return d_func()->m_redirectionURL;
 }
 
-// Slave requests data
+// Worker requests data
 void TransferJob::slotDataReq()
 {
     Q_D(TransferJob);
-    QByteArray dataForSlave;
+    QByteArray dataForWorker;
 
     d->m_extraFlags |= JobPrivate::EF_TransferJobNeedData;
 
     if (!d->staticData.isEmpty()) {
-        dataForSlave = d->staticData;
+        dataForWorker = d->staticData;
         d->staticData.clear();
     } else {
-        emit dataReq(this, dataForSlave);
+        Q_EMIT dataReq(this, dataForWorker);
 
         if (d->m_extraFlags & JobPrivate::EF_TransferJobAsync) {
             return;
@@ -234,19 +213,14 @@ void TransferJob::slotDataReq()
     }
 
     static const int max_size = 14 * 1024 * 1024;
-    if (dataForSlave.size() > max_size) {
-        //qDebug() << "send" << dataForSlave.size() / 1024 / 1024 << "MB of data in TransferJob::dataReq. This needs to be split, which requires a copy. Fix the application.";
-        d->staticData = QByteArray(dataForSlave.data() + max_size,  dataForSlave.size() - max_size);
-        dataForSlave.truncate(max_size);
+    if (dataForWorker.size() > max_size) {
+        // qDebug() << "send" << dataForWorker.size() / 1024 / 1024 << "MB of data in TransferJob::dataReq. This needs to be split, which requires a copy. Fix
+        // the application.";
+        d->staticData = QByteArray(dataForWorker.data() + max_size, dataForWorker.size() - max_size);
+        dataForWorker.truncate(max_size);
     }
 
-    sendAsyncData(dataForSlave);
-
-    if (d->m_subJob) {
-        // Bitburger protocol in action
-        d->internalSuspend(); // Wait for more data from subJob.
-        d->m_subJob->d_func()->internalResume(); // Ask for more!
-    }
+    sendAsyncData(dataForWorker);
 }
 
 void TransferJob::slotMimetype(const QString &type)
@@ -257,25 +231,22 @@ void TransferJob::slotMimetype(const QString &type)
         qCWarning(KIO_CORE) << "mimetype() emitted again, or after sending first data!; job URL =" << d->m_url;
     }
     d->m_isMimetypeEmitted = true;
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 78)
-    emit mimetype(this, type);
-#endif
-    emit mimeTypeFound(this, type);
+    Q_EMIT mimeTypeFound(this, type);
 }
 
 void TransferJobPrivate::internalSuspend()
 {
     m_internalSuspended = true;
-    if (m_slave) {
-        m_slave->suspend();
+    if (m_worker) {
+        m_worker->suspend();
     }
 }
 
 void TransferJobPrivate::internalResume()
 {
     m_internalSuspended = false;
-    if (m_slave && !q_func()->isSuspended()) {
-        m_slave->resume();
+    if (m_worker && !q_func()->isSuspended()) {
+        m_worker->resume();
     }
 }
 
@@ -296,132 +267,94 @@ bool TransferJob::isErrorPage() const
     return d_func()->m_errorPage;
 }
 
-void TransferJobPrivate::start(Slave *slave)
+void TransferJobPrivate::start(Worker *worker)
 {
     Q_Q(TransferJob);
-    Q_ASSERT(slave);
+    Q_ASSERT(worker);
     JobPrivate::emitTransferring(q, m_url);
-    q->connect(slave, &SlaveInterface::data,
-               q, &TransferJob::slotData);
+    q->connect(worker, &WorkerInterface::data, q, &TransferJob::slotData);
 
     if (m_outgoingDataSource) {
         if (m_extraFlags & JobPrivate::EF_TransferJobAsync) {
-            q->connect(m_outgoingDataSource, &QIODevice::readyRead, q, [this]() {
+            auto dataReqFunc = [this]() {
                 slotDataReqFromDevice();
-            });
-            q->connect(m_outgoingDataSource, SIGNAL(readChannelFinished()),
-                    SLOT(slotIODeviceClosed()));
+            };
+            q->connect(m_outgoingDataSource, &QIODevice::readyRead, q, dataReqFunc);
+            auto ioClosedFunc = [this]() {
+                slotIODeviceClosed();
+            };
+            q->connect(m_outgoingDataSource, &QIODevice::readChannelFinished, q, ioClosedFunc);
             // We don't really need to disconnect since we're never checking
             // m_closedBeforeStart again but it's the proper thing to do logically
-            QObject::disconnect(m_outgoingDataSource, SIGNAL(readChannelFinished()),
-                                q, SLOT(slotIODeviceClosedBeforeStart()));
+            QObject::disconnect(m_readChannelFinishedConnection);
             if (m_closedBeforeStart) {
-                QMetaObject::invokeMethod(q, "slotIODeviceClosed", Qt::QueuedConnection);
+                QMetaObject::invokeMethod(q, ioClosedFunc, Qt::QueuedConnection);
             } else if (m_outgoingDataSource->bytesAvailable() > 0) {
-                QMetaObject::invokeMethod(q, "slotDataReqFromDevice", Qt::QueuedConnection);
+                QMetaObject::invokeMethod(q, dataReqFunc, Qt::QueuedConnection);
             }
         } else {
-            q->connect(slave, &SlaveInterface::dataReq, q, [this]() {
+            q->connect(worker, &WorkerInterface::dataReq, q, [this]() {
                 slotDataReqFromDevice();
             });
         }
-    } else
-        q->connect(slave, &SlaveInterface::dataReq,
-                   q, &TransferJob::slotDataReq);
+    } else {
+        q->connect(worker, &WorkerInterface::dataReq, q, &TransferJob::slotDataReq);
+    }
 
-    q->connect(slave, &SlaveInterface::redirection,
-               q, &TransferJob::slotRedirection);
+    q->connect(worker, &WorkerInterface::redirection, q, &TransferJob::slotRedirection);
 
-    q->connect(slave, &SlaveInterface::mimeType,
-               q, &TransferJob::slotMimetype);
+    q->connect(worker, &WorkerInterface::mimeType, q, &TransferJob::slotMimetype);
 
-    q->connect(slave, &SlaveInterface::errorPage, q, [this]() {
+    q->connect(worker, &WorkerInterface::errorPage, q, [this]() {
         m_errorPage = true;
     });
 
-    q->connect(slave, &SlaveInterface::needSubUrlData, q, [this]() {
-        slotNeedSubUrlData();
+    q->connect(worker, &WorkerInterface::canResume, q, [q](KIO::filesize_t offset) {
+        Q_EMIT q->canResume(q, offset);
     });
 
-    q->connect(slave, &SlaveInterface::canResume, q, [q](KIO::filesize_t offset) {
-        emit q->canResume(q, offset);
-    });
-
-    if (slave->suspended()) {
+    if (worker->suspended()) {
         m_mimetype = QStringLiteral("unknown");
-        // WABA: The slave was put on hold. Resume operation.
-        slave->resume();
+        // WABA: The worker was put on hold. Resume operation.
+        worker->resume();
     }
 
-    SimpleJobPrivate::start(slave);
+    SimpleJobPrivate::start(worker);
     if (m_internalSuspended) {
-        slave->suspend();
+        worker->suspend();
     }
 }
 
-void TransferJobPrivate::slotNeedSubUrlData()
-{
-    Q_Q(TransferJob);
-    // Job needs data from subURL.
-    m_subJob = KIO::get(m_subUrl, NoReload, HideProgressInfo);
-    internalSuspend(); // Put job on hold until we have some data.
-    q->connect(m_subJob, &TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
-        slotSubUrlData(job, data);
-    });
-    q->addSubjob(m_subJob);
-}
-
-void TransferJobPrivate::slotSubUrlData(KIO::Job *, const QByteArray &data)
-{
-    // The Alternating Bitburg protocol in action again.
-    staticData = data;
-    m_subJob->d_func()->internalSuspend(); // Put job on hold until we have delivered the data.
-    internalResume(); // Activate ourselves again.
-}
-
-void TransferJob::slotMetaData(const KIO::MetaData &_metaData)
-{
-    Q_D(TransferJob);
-    SimpleJob::slotMetaData(_metaData);
-    storeSSLSessionFromJob(d->m_redirectionURL);
-}
-
 void TransferJobPrivate::slotDataReqFromDevice()
 {
     Q_Q(TransferJob);
 
     bool done = false;
-    QByteArray dataForSlave;
+    QByteArray dataForWorker;
 
     m_extraFlags |= JobPrivate::EF_TransferJobNeedData;
 
     if (m_outgoingDataSource) {
-        dataForSlave.resize(MAX_READ_BUF_SIZE);
+        dataForWorker.resize(MAX_READ_BUF_SIZE);
 
-        //Code inspired in QNonContiguousByteDevice
-        qint64 bytesRead = m_outgoingDataSource->read(dataForSlave.data(), MAX_READ_BUF_SIZE);
+        // Code inspired in QNonContiguousByteDevice
+        qint64 bytesRead = m_outgoingDataSource->read(dataForWorker.data(), MAX_READ_BUF_SIZE);
         if (bytesRead >= 0) {
-            dataForSlave.resize(bytesRead);
+            dataForWorker.resize(bytesRead);
         } else {
-            dataForSlave.clear();
+            dataForWorker.clear();
         }
         done = ((bytesRead == -1) || (bytesRead == 0 && m_outgoingDataSource->atEnd() && !m_outgoingDataSource->isSequential()));
     }
 
-    if (dataForSlave.isEmpty()) {
-        emit q->dataReq(q, dataForSlave);
+    if (dataForWorker.isEmpty()) {
+        Q_EMIT q->dataReq(q, dataForWorker);
         if (!done && (m_extraFlags & JobPrivate::EF_TransferJobAsync)) {
             return;
         }
     }
 
-    q->sendAsyncData(dataForSlave);
-
-    if (m_subJob) {
-        // Bitburger protocol in action
-        internalSuspend(); // Wait for more data from subJob.
-        m_subJob->d_func()->internalResume(); // Ask for more!
-    }
+    q->sendAsyncData(dataForWorker);
 }
 
 void TransferJobPrivate::slotIODeviceClosedBeforeStart()
@@ -440,28 +373,8 @@ void TransferJobPrivate::slotIODeviceClosed()
 
     m_extraFlags |= JobPrivate::EF_TransferJobNeedData;
 
-    //We send an empty data array to indicate the stream is over
+    // We send an empty data array to indicate the stream is over
     q->sendAsyncData(QByteArray());
-
-    if (m_subJob) {
-        // Bitburger protocol in action
-        internalSuspend(); // Wait for more data from subJob.
-        m_subJob->d_func()->internalResume(); // Ask for more!
-    }
-}
-
-void TransferJob::slotResult(KJob *job)
-{
-    Q_D(TransferJob);
-    // This can only be our suburl.
-    Q_ASSERT(job == d->m_subJob);
-
-    SimpleJob::slotResult(job);
-
-    if (!error() && job == d->m_subJob) {
-        d->m_subJob = nullptr; // No action required
-        d->internalResume(); // Make sure we get the remaining data.
-    }
 }
 
 void TransferJob::setModificationTime(const QDateTime &mtime)
@@ -473,8 +386,7 @@ TransferJob *KIO::get(const QUrl &url, LoadType reload, JobFlags flags)
 {
     // Send decoded path and encoded query
     KIO_ARGS << url;
-    TransferJob *job = TransferJobPrivate::newJob(url, CMD_GET, packedArgs,
-                       QByteArray(), flags);
+    TransferJob *job = TransferJobPrivate::newJob(url, CMD_GET, packedArgs, QByteArray(), flags);
     if (reload == Reload) {
         job->addMetaData(QStringLiteral("cache"), QStringLiteral("reload"));
     }
