@@ -139,28 +139,6 @@ public:
      */
     void reserve(int size);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 48)
-    /**
-     * insert field with string value
-     * @param field numeric field id
-     * @param value to set
-     * @deprecated since 5.48 in favor of fastInsert or replace
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 48, "Use UDSEntry::fastInsert(uint, const QString &) or UDSEntry::replace(uint, const QString &)")
-    void insert(uint field, const QString &value);
-#endif
-
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 48)
-    /**
-     * insert field with numeric value
-     * @param field numeric field id
-     * @param l value to set
-     * @deprecated since 5.48 in favor of fastInsert or replace
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 48, "Use UDSEntry::fastInsert(uint, long long) or UDSEntry::replace(uint, long long)")
-    void insert(uint field, long long l);
-#endif
-
     /**
      * insert field with string value, it will assert if the field is already inserted. In that case, use replace() instead.
      * @param field numeric field id
@@ -189,22 +167,12 @@ public:
      */
     bool contains(uint field) const;
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 8)
-    /**
-     * List all fields.
-     * @return all fields.
-     * @deprecated since 5.8. Use fields() instead.
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 8, "Use UDSEntry::fields()")
-    QList<uint> listFields() const;
-#endif
-
     /**
      * A vector of fields being present for the current entry.
      * @return all fields for the current entry.
      * @since 5.8
      */
-    QVector<uint> fields() const;
+    QList<uint> fields() const;
 
     /**
      * remove all fields
@@ -212,42 +180,49 @@ public:
     void clear();
 
     /**
-     * Constants used to specify the type of a UDSField.
+     * Bit field used to specify the item type of a StandardFieldTypes.
      */
-    enum StandardFieldTypes {
-        // First let's define the item types: bit field
-
+    enum ItemTypes {
+        // Those are a bit field
         /// Indicates that the field is a QString
         UDS_STRING = 0x01000000,
         /// Indicates that the field is a number (long long)
         UDS_NUMBER = 0x02000000,
         /// Indicates that the field represents a time, which is modelled by a long long
         UDS_TIME = 0x04000000 | UDS_NUMBER,
+    };
 
-        // The rest isn't a bit field
+    /**
+     * Constants used to specify the type of a UDSEntry’s field.
+     */
+    enum StandardFieldTypes {
+
+        // The highest bit is reserved to store the used FieldTypes
 
         /// Size of the file
         UDS_SIZE = 1 | UDS_NUMBER,
         /// @internal
         UDS_SIZE_LARGE = 2 | UDS_NUMBER,
-        /// User ID of the file owner
+        /// User Name of the file owner
+        /// Not present on local fs, use UDS_LOCAL_USER_ID
         UDS_USER = 3 | UDS_STRING,
         /// Name of the icon, that should be used for displaying.
         /// It overrides all other detection mechanisms
         UDS_ICON_NAME = 4 | UDS_STRING,
-        /// Group ID of the file owner
+        /// Group Name of the file owner
+        /// Not present on local fs, use UDS_LOCAL_GROUP_ID
         UDS_GROUP = 5 | UDS_STRING,
         /// Filename - as displayed in directory listings etc.
         /// "." has the usual special meaning of "current directory"
         /// UDS_NAME must always be set and never be empty, neither contain '/'.
         ///
         /// Note that KIO will append the UDS_NAME to the url of their
-        /// parent directory, so all kioslaves must use that naming scheme
+        /// parent directory, so all KIO workers must use that naming scheme
         /// ("url_of_parent/filename" will be the full url of that file).
         /// To customize the appearance of files without changing the url
         /// of the items, use UDS_DISPLAY_NAME.
         UDS_NAME = 6 | UDS_STRING,
-        /// A local file path if the ioslave display files sitting
+        /// A local file path if the KIO worker display files sitting
         /// on the local filesystem (but in another hierarchy, e.g.\ settings:/ or remote:/)
         UDS_LOCAL_PATH = 7 | UDS_STRING,
         /// Treat the file as a hidden file (if set to 1) or as a normal file (if set to 0).
@@ -274,7 +249,7 @@ public:
         /// Use UDS_DISPLAY_NAME if you simply want to customize the user-visible filenames, or use
         /// UDS_TARGET_URL if you want "links" to unrelated urls.
         UDS_URL = 15 | UDS_STRING,
-        /// A MIME type; the slave should set it if it's known.
+        /// A MIME type; the KIO worker should set it if it's known.
         UDS_MIME_TYPE = 16 | UDS_STRING,
         /// A MIME type to be used for displaying only.
         /// But when 'running' the file, the MIME type is re-determined
@@ -305,33 +280,36 @@ public:
         /// @since 4.4
         UDS_DISPLAY_TYPE = 24 | UDS_STRING,
 
-        /// 25 was used by the now removed UDS_NEPOMUK_URI
-
         /// A comma-separated list of supplementary icon overlays
         /// which will be added to the list of overlays created
         /// by KFileItem.
         ///
         /// @since 4.5
-        UDS_ICON_OVERLAY_NAMES = 26 | UDS_STRING,
-
-        /// 27 was used by the now removed UDS_NEPOMUK_QUERY
+        UDS_ICON_OVERLAY_NAMES = 25 | UDS_STRING,
 
         /// A comment which will be displayed as is to the user. The string
         /// value may contain plain text or Qt-style rich-text extensions.
         ///
         /// @since 4.6
-        UDS_COMMENT = 28 | UDS_STRING,
+        UDS_COMMENT = 26 | UDS_STRING,
 
         /// Device number for this file, used to detect hardlinks
         /// @since 4.7.3
-        UDS_DEVICE_ID = 29 | UDS_NUMBER,
+        UDS_DEVICE_ID = 27 | UDS_NUMBER,
         /// Inode number for this file, used to detect hardlinks
         /// @since 4.7.3
-        UDS_INODE = 30 | UDS_NUMBER,
+        UDS_INODE = 28 | UDS_NUMBER,
 
         /// For folders, the recursize size of its content
         /// @since 5.70
-        UDS_RECURSIVE_SIZE = 31 | UDS_NUMBER,
+        UDS_RECURSIVE_SIZE = 29 | UDS_NUMBER,
+
+        /// User ID of the file owner
+        /// @since 6.0
+        UDS_LOCAL_USER_ID = 30 | UDS_NUMBER,
+        /// Group ID of the file owner
+        /// @since 6.0
+        UDS_LOCAL_GROUP_ID = 31 | UDS_NUMBER,
 
         /// Extra data (used only if you specified Columns/ColumnsTypes)
         /// NB: you cannot repeat this entry; use UDS_EXTRA + i
@@ -369,7 +347,7 @@ public:
 
 }
 
-Q_DECLARE_TYPEINFO(KIO::UDSEntry, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KIO::UDSEntry, Q_RELOCATABLE_TYPE);
 
 namespace KIO
 {
