@@ -19,6 +19,7 @@
 #include <KMountPoint>
 #include <kprotocolinfo.h>
 #include <solid/block.h>
+#include <solid/genericinterface.h>
 #include <solid/networkshare.h>
 #include <solid/opticaldisc.h>
 #include <solid/opticaldrive.h>
@@ -42,8 +43,10 @@ KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &addre
     , m_isTeardownOverlayRecommended(false)
     , m_isTeardownInProgress(false)
     , m_isSetupInProgress(false)
+    , m_isReadOnly(false)
 {
     updateDeviceInfo(udi);
+
     setBookmark(m_manager->findByAddress(address));
 
     if (udi.isEmpty() && m_bookmark.metaDataItem(QStringLiteral("ID")).isEmpty()) {
@@ -51,7 +54,7 @@ KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &addre
     } else if (udi.isEmpty()) {
         if (isTrash(m_bookmark)) {
             KConfig cfg(QStringLiteral("trashrc"), KConfig::SimpleConfig);
-            const KConfigGroup group = cfg.group("Status");
+            const KConfigGroup group = cfg.group(QStringLiteral("Status"));
             m_folderIsEmpty = group.readEntry("Empty", true);
         }
     }
@@ -158,7 +161,12 @@ void KFilePlacesItem::setBookmark(const KBookmark &bookmark)
 {
     m_bookmark = bookmark;
 
-    updateDeviceInfo(m_bookmark.metaDataItem(QStringLiteral("UDI")));
+    if (m_device.isValid()) {
+        m_bookmark.setMetaDataItem(QStringLiteral("UDI"), m_device.udi());
+        if (m_volume && !m_volume->uuid().isEmpty()) {
+            m_bookmark.setMetaDataItem(QStringLiteral("uuid"), m_volume->uuid());
+        }
+    }
 
     if (bookmark.metaDataItem(QStringLiteral("isSystemItem")) == QLatin1String("true")) {
         // This context must stay as it is - the translated system bookmark names
@@ -365,7 +373,7 @@ QVariant KFilePlacesItem::deviceData(int role) const
         }
 
         case KFilePlacesModel::CapacityBarRecommendedRole:
-            return m_isAccessible && !m_isCdrom && !m_networkShare;
+            return m_isAccessible && !m_isCdrom && !m_networkShare && !m_isReadOnly;
 
         case KFilePlacesModel::IconNameRole:
             return m_deviceIconName;
@@ -418,15 +426,20 @@ KBookmark KFilePlacesItem::createSystemBookmark(KBookmarkManager *manager,
     return bookmark;
 }
 
-KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager, const QString &udi)
+KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager, const Solid::Device &device)
 {
     KBookmarkGroup root = manager->root();
     if (root.isNull()) {
         return KBookmark();
     }
     KBookmark bookmark = root.createNewSeparator();
-    bookmark.setMetaDataItem(QStringLiteral("UDI"), udi);
+    bookmark.setMetaDataItem(QStringLiteral("UDI"), device.udi());
     bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
+
+    const auto storage = device.as<Solid::StorageVolume>();
+    if (storage) {
+        bookmark.setMetaDataItem(QStringLiteral("uuid"), storage->uuid());
+    }
     return bookmark;
 }
 
@@ -526,6 +539,11 @@ void KFilePlacesItem::onAccessibilityChanged(bool isAccessible)
         m_device.is<Solid::OpticalDrive>() || m_device.parent().is<Solid::OpticalDrive>() || (m_volume && m_volume->fsType() == QLatin1String("iso9660"));
     m_emblems = m_device.emblems();
 
+    if (auto generic = m_device.as<Solid::GenericInterface>()) {
+        // TODO add Solid API for this.
+        m_isReadOnly = generic->property(QStringLiteral("ReadOnly")).toBool();
+    }
+
     m_isTeardownAllowed = isAccessible;
     if (m_isTeardownAllowed) {
         if (m_access->filePath() == QDir::rootPath()) {
