@@ -2,6 +2,7 @@
     This file is part of the KDE project
     SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
     SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -9,36 +10,21 @@
 #include "kfileplacesmodel.h"
 #include "kfileplacesitem_p.h"
 
-#ifdef _WIN32_WCE
-#include "WinBase.h"
-#include "Windows.h"
-#endif
-
-#include <QAction>
-#include <QCoreApplication>
-#include <QDir>
-#include <QFile>
-#include <QMimeData>
-#include <QMimeDatabase>
-#include <QTimer>
-
-#include <KLazyLocalizedString>
-#include <KLocalizedString>
-#include <kfileitem.h>
-
-#include <KUrlMimeData>
-#include <QDebug>
-
-#include <KBookmarkManager>
-
 #include <KCoreDirLister>
-#include <kio/job.h>
+#include <KLazyLocalizedString>
+#include <KListOpenFilesJob>
+#include <KLocalizedString>
+#include <commandlauncherjob.h>
+#include <kfileitem.h>
+#include <kio/statjob.h>
 #include <kprotocolinfo.h>
 
+#include <KBookmarkManager>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KUrlMimeData>
 
-#include <QStandardPaths>
+#include <solid/block.h>
 #include <solid/devicenotifier.h>
 #include <solid/opticaldisc.h>
 #include <solid/opticaldrive.h>
@@ -48,6 +34,16 @@
 #include <solid/storagedrive.h>
 #include <solid/storagevolume.h>
 
+#include <QAction>
+#include <QCoreApplication>
+#include <QDebug>
+#include <QDir>
+#include <QFile>
+#include <QMimeData>
+#include <QMimeDatabase>
+#include <QStandardPaths>
+#include <QTimer>
+
 namespace
 {
 QString stateNameForGroupType(KFilePlacesModel::GroupType type)
@@ -75,7 +71,7 @@ QString stateNameForGroupType(KFilePlacesModel::GroupType type)
 static bool isFileIndexingEnabled()
 {
     KConfig config(QStringLiteral("baloofilerc"));
-    KConfigGroup basicSettings = config.group("Basic Settings");
+    KConfigGroup basicSettings = config.group(QStringLiteral("Basic Settings"));
     return basicSettings.readEntry("Indexing-Enabled", true);
 }
 
@@ -194,8 +190,9 @@ public:
     KFilePlacesModel *const q;
 
     QList<KFilePlacesItem *> items;
-    QVector<QString> availableDevices;
+    QList<Solid::Device> availableDevices;
     QMap<QObject *, QPersistentModelIndex> setupInProgress;
+    QMap<QObject *, QPersistentModelIndex> teardownInProgress;
     QStringList supportedSchemes;
 
     Solid::Predicate predicate;
@@ -203,23 +200,21 @@ public:
 
     const bool fileIndexingEnabled;
 
-    QString alternativeApplicationName;
-
     void reloadAndSignal();
     QList<KFilePlacesItem *> loadBookmarkList();
     int findNearestPosition(int source, int target);
 
-    QVector<QString> tags;
+    QList<QString> tags;
     const QString tagsUrlBase = QStringLiteral("tags:/");
     KCoreDirLister *tagsLister;
 
     void initDeviceList();
     void deviceAdded(const QString &udi);
     void deviceRemoved(const QString &udi);
-    void itemChanged(const QString &udi);
+    void itemChanged(const QString &udi, const QList<int> &roles);
     void reloadBookmarks();
     void storageSetupDone(Solid::ErrorType error, const QVariant &errorData, Solid::StorageAccess *sender);
-    void storageTeardownDone(Solid::ErrorType error, const QVariant &errorData);
+    void storageTeardownDone(const QString &filePath, Solid::ErrorType error, const QVariant &errorData, QObject *sender);
 
 private:
     bool isBalooUrl(const QUrl &url) const;
@@ -243,13 +238,12 @@ static inline QString versionKey()
     return QStringLiteral("kde_places_version");
 }
 
-KFilePlacesModel::KFilePlacesModel(const QString &alternativeApplicationName, QObject *parent)
+KFilePlacesModel::KFilePlacesModel(QObject *parent)
     : QAbstractItemModel(parent)
     , d(new KFilePlacesModelPrivate(this))
 {
     const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/user-places.xbel");
-    d->bookmarkManager = KBookmarkManager::managerForExternalFile(file);
-    d->alternativeApplicationName = alternativeApplicationName;
+    d->bookmarkManager = new KBookmarkManager(file, this);
 
     // Let's put some places in there if it's empty.
     KBookmarkGroup root = d->bookmarkManager->root();
@@ -459,23 +453,6 @@ KFilePlacesModel::KFilePlacesModel(const QString &alternativeApplicationName, QO
                                                   QStringLiteral("view-calendar-day"));
         }
 
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              kli18nc("KFile System Bookmarks", "Documents").untranslatedText(),
-                                              QUrl(QStringLiteral("search:/documents")),
-                                              QStringLiteral("folder-text"));
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              kli18nc("KFile System Bookmarks", "Images").untranslatedText(),
-                                              QUrl(QStringLiteral("search:/images")),
-                                              QStringLiteral("folder-images"));
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              kli18nc("KFile System Bookmarks", "Audio").untranslatedText(),
-                                              QUrl(QStringLiteral("search:/audio")),
-                                              QStringLiteral("folder-sound"));
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              kli18nc("KFile System Bookmarks", "Videos").untranslatedText(),
-                                              QUrl(QStringLiteral("search:/videos")),
-                                              QStringLiteral("folder-videos"));
-
         setDefaultMetadataItemForGroup(SearchForType);
         setDefaultMetadataItemForGroup(RecentlySavedType);
 
@@ -515,11 +492,6 @@ KFilePlacesModel::KFilePlacesModel(const QString &alternativeApplicationName, QO
     });
 }
 
-KFilePlacesModel::KFilePlacesModel(QObject *parent)
-    : KFilePlacesModel({}, parent)
-{
-}
-
 KFilePlacesModel::~KFilePlacesModel() = default;
 
 QUrl KFilePlacesModel::url(const QModelIndex &index) const
@@ -585,6 +557,36 @@ bool KFilePlacesModel::isTeardownAllowed(const QModelIndex &index) const
     return item->isTeardownAllowed();
 }
 
+bool KFilePlacesModel::isEjectAllowed(const QModelIndex &index) const
+{
+    if (!index.isValid()) {
+        return false;
+    }
+
+    KFilePlacesItem *item = static_cast<KFilePlacesItem *>(index.internalPointer());
+    return item->isEjectAllowed();
+}
+
+bool KFilePlacesModel::isTeardownOverlayRecommended(const QModelIndex &index) const
+{
+    if (!index.isValid()) {
+        return false;
+    }
+
+    KFilePlacesItem *item = static_cast<KFilePlacesItem *>(index.internalPointer());
+    return item->isTeardownOverlayRecommended();
+}
+
+KFilePlacesModel::DeviceAccessibility KFilePlacesModel::deviceAccessibility(const QModelIndex &index) const
+{
+    if (!index.isValid()) {
+        return KFilePlacesModel::Accessible;
+    }
+
+    KFilePlacesItem *item = static_cast<KFilePlacesItem *>(index.internalPointer());
+    return item->deviceAccessibility();
+}
+
 Solid::Device KFilePlacesModel::deviceForIndex(const QModelIndex &index) const
 {
     if (!index.isValid()) {
@@ -684,6 +686,9 @@ QHash<int, QByteArray> KFilePlacesModel::roleNames() const
     super[IconNameRole] = "iconName";
     super[GroupHiddenRole] = "isGroupHidden";
     super[TeardownAllowedRole] = "isTeardownAllowed";
+    super[EjectAllowedRole] = "isEjectAllowed";
+    super[TeardownOverlayRecommendedRole] = "isTeardownOverlayRecommended";
+    super[DeviceAccessibilityRole] = "deviceAccessibility";
 
     return super;
 }
@@ -749,12 +754,7 @@ void KFilePlacesModelPrivate::initDeviceList()
         deviceRemoved(device);
     });
 
-    const QList<Solid::Device> &deviceList = Solid::Device::listFromQuery(predicate);
-
-    availableDevices.reserve(deviceList.size());
-    for (const Solid::Device &device : deviceList) {
-        availableDevices << device.udi();
-    }
+    availableDevices = Solid::Device::listFromQuery(predicate);
 
     reloadBookmarks();
 }
@@ -764,26 +764,28 @@ void KFilePlacesModelPrivate::deviceAdded(const QString &udi)
     Solid::Device d(udi);
 
     if (predicate.matches(d)) {
-        availableDevices << udi;
+        availableDevices << d;
         reloadBookmarks();
     }
 }
 
 void KFilePlacesModelPrivate::deviceRemoved(const QString &udi)
 {
-    auto it = std::find(availableDevices.begin(), availableDevices.end(), udi);
+    auto it = std::find_if(availableDevices.begin(), availableDevices.end(), [udi](const Solid::Device &device) {
+        return device.udi() == udi;
+    });
     if (it != availableDevices.end()) {
         availableDevices.erase(it);
         reloadBookmarks();
     }
 }
 
-void KFilePlacesModelPrivate::itemChanged(const QString &id)
+void KFilePlacesModelPrivate::itemChanged(const QString &id, const QList<int> &roles)
 {
     for (int row = 0; row < items.size(); ++row) {
         if (items.at(row)->id() == id) {
             QModelIndex index = q->index(row, 0);
-            Q_EMIT q->dataChanged(index, index);
+            Q_EMIT q->dataChanged(index, index, roles);
         }
     }
 }
@@ -874,71 +876,67 @@ QList<KFilePlacesItem *> KFilePlacesModelPrivate::loadBookmarkList()
 
     KBookmarkGroup root = bookmarkManager->root();
     KBookmark bookmark = root.first();
-    QVector<QString> devices = availableDevices;
-    QVector<QString> tagsList = tags;
+    QList<Solid::Device> devices{availableDevices};
+    QList<QString> tagsList = tags;
 
     while (!bookmark.isNull()) {
-        const QString udi = bookmark.metaDataItem(QStringLiteral("UDI"));
-        const QUrl url = bookmark.url();
-        const QString tag = bookmark.metaDataItem(QStringLiteral("tag"));
-        if (!udi.isEmpty() || url.isValid()) {
-            QString appName = bookmark.metaDataItem(QStringLiteral("OnlyInApp"));
+        KFilePlacesItem *item = nullptr;
 
-            // If it's not a tag it's a device
-            if (tag.isEmpty()) {
-                auto it = std::find(devices.begin(), devices.end(), udi);
-                bool deviceAvailable = (it != devices.end());
-                if (deviceAvailable) {
-                    devices.erase(it);
-                }
-
-                bool allowedHere =
-                    appName.isEmpty() || ((appName == QCoreApplication::instance()->applicationName()) || (appName == alternativeApplicationName));
-                bool isSupportedUrl = isBalooUrl(url) ? fileIndexingEnabled : true;
-                bool isSupportedScheme = supportedSchemes.isEmpty() || supportedSchemes.contains(url.scheme());
-
-                KFilePlacesItem *item = nullptr;
-                if (deviceAvailable) {
-                    item = new KFilePlacesItem(bookmarkManager, bookmark.address(), udi, q);
-                    if (!item->hasSupportedScheme(supportedSchemes)) {
-                        delete item;
-                        item = nullptr;
+        if (const QString udi = bookmark.metaDataItem(QStringLiteral("UDI")); !udi.isEmpty()) {
+            const QString uuid = bookmark.metaDataItem(QStringLiteral("uuid"));
+            auto it = std::find_if(devices.begin(), devices.end(), [udi, uuid](const Solid::Device &device) {
+                if (!uuid.isEmpty()) {
+                    auto storageVolume = device.as<Solid::StorageVolume>();
+                    if (storageVolume && !storageVolume->uuid().isEmpty()) {
+                        return storageVolume->uuid() == uuid;
                     }
-                } else if (isSupportedScheme && isSupportedUrl && udi.isEmpty() && allowedHere) {
-                    // TODO: Update bookmark internal element
-                    item = new KFilePlacesItem(bookmarkManager, bookmark.address(), QString(), q);
                 }
 
-                if (item) {
-                    QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id) {
-                        itemChanged(id);
-                    });
-
-                    items << item;
-                }
-            } else {
-                auto it = std::find(tagsList.begin(), tagsList.end(), tag);
-                if (it != tagsList.end()) {
-                    tagsList.removeAll(tag);
-                    KFilePlacesItem *item = new KFilePlacesItem(bookmarkManager, bookmark.address(), QString(), q);
-                    items << item;
-                    QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id) {
-                        itemChanged(id);
-                    });
+                return device.udi() == udi;
+            });
+            if (it != devices.end()) {
+                item = new KFilePlacesItem(bookmarkManager, bookmark.address(), it->udi(), q);
+                if (!item->hasSupportedScheme(supportedSchemes)) {
+                    delete item;
+                    item = nullptr;
                 }
+                devices.erase(it);
             }
+        } else if (const QString tag = bookmark.metaDataItem(QStringLiteral("tag")); !tag.isEmpty()) {
+            auto it = std::find(tagsList.begin(), tagsList.end(), tag);
+            if (it != tagsList.end()) {
+                tagsList.erase(it);
+                item = new KFilePlacesItem(bookmarkManager, bookmark.address(), QString(), q);
+            }
+        } else if (const QUrl url = bookmark.url(); url.isValid()) {
+            QString appName = bookmark.metaDataItem(QStringLiteral("OnlyInApp"));
+            bool allowedHere = appName.isEmpty() || appName == QCoreApplication::instance()->applicationName();
+            bool isSupportedUrl = isBalooUrl(url) ? fileIndexingEnabled : true;
+            bool isSupportedScheme = supportedSchemes.isEmpty() || supportedSchemes.contains(url.scheme());
+
+            if (isSupportedScheme && isSupportedUrl && allowedHere) {
+                // TODO: Update bookmark internal element
+                item = new KFilePlacesItem(bookmarkManager, bookmark.address(), QString(), q);
+            }
+        }
+
+        if (item) {
+            QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id, const QList<int> &roles) {
+                itemChanged(id, roles);
+            });
+            items << item;
         }
 
         bookmark = root.next(bookmark);
     }
 
     // Add bookmarks for the remaining devices, they were previously unknown
-    for (const QString &udi : std::as_const(devices)) {
-        bookmark = KFilePlacesItem::createDeviceBookmark(bookmarkManager, udi);
+    for (const Solid::Device &device : std::as_const(devices)) {
+        bookmark = KFilePlacesItem::createDeviceBookmark(bookmarkManager, device);
         if (!bookmark.isNull()) {
-            KFilePlacesItem *item = new KFilePlacesItem(bookmarkManager, bookmark.address(), udi, q);
-            QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id) {
-                itemChanged(id);
+            KFilePlacesItem *item = new KFilePlacesItem(bookmarkManager, bookmark.address(), device.udi(), q);
+            QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id, const QList<int> &roles) {
+                itemChanged(id, roles);
             });
             // TODO: Update bookmark internal element
             items << item;
@@ -949,8 +947,8 @@ QList<KFilePlacesItem *> KFilePlacesModelPrivate::loadBookmarkList()
         bookmark = KFilePlacesItem::createTagBookmark(bookmarkManager, tag);
         if (!bookmark.isNull()) {
             KFilePlacesItem *item = new KFilePlacesItem(bookmarkManager, bookmark.address(), tag, q);
-            QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id) {
-                itemChanged(id);
+            QObject::connect(item, &KFilePlacesItem::itemChanged, q, [this](const QString &id, const QList<int> &roles) {
+                itemChanged(id, roles);
             });
             items << item;
         }
@@ -1123,7 +1121,7 @@ bool KFilePlacesModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         KBookmarkGroup group = d->bookmarkManager->root();
 
         for (const QUrl &url : urls) {
-            KIO::StatJob *job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatBasic);
+            KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatBasic);
 
             if (!job->exec()) {
                 Q_EMIT errorMessage(i18nc("Placeholder is error message", "Could not add to the Places panel: %1", job->errorString()));
@@ -1210,7 +1208,7 @@ void KFilePlacesModel::editPlace(const QModelIndex &index, const QString &text,
         return;
     }
 
-    QVector<int> changedRoles;
+    QList<int> changedRoles;
     bool changed = false;
 
     if (text != bookmark.fullText()) {
@@ -1285,7 +1283,7 @@ void KFilePlacesModel::setPlaceHidden(const QModelIndex &index, bool hidden)
         item->setHidden(hidden);
 
         d->reloadAndSignal();
-        Q_EMIT dataChanged(index, index, { KFilePlacesModel::HiddenRole });
+        Q_EMIT dataChanged(index, index, {KFilePlacesModel::HiddenRole});
     }
 }
 
@@ -1373,6 +1371,8 @@ QAction *KFilePlacesModel::teardownActionForIndex(const QModelIndex &index) cons
 {
     Solid::Device device = deviceForIndex(index);
 
+    QAction *action = nullptr;
+
     if (device.is<Solid::StorageAccess>() && device.as<Solid::StorageAccess>()->isAccessible()) {
         Solid::StorageDrive *drive = device.as<Solid::StorageDrive>();
 
@@ -1380,6 +1380,8 @@ QAction *KFilePlacesModel::teardownActionForIndex(const QModelIndex &index) cons
             drive = device.parent().as<Solid::StorageDrive>();
         }
 
+        const bool teardownInProgress = deviceAccessibility(index) == KFilePlacesModel::TeardownInProgress;
+
         bool hotpluggable = false;
         bool removable = false;
 
@@ -1392,23 +1394,39 @@ QAction *KFilePlacesModel::teardownActionForIndex(const QModelIndex &index) cons
         QString text;
 
         if (device.is<Solid::OpticalDisc>()) {
-            text = i18nc("@action:inmenu", "&Release");
+            if (teardownInProgress) {
+                text = i18nc("@action:inmenu", "Releasing…");
+            } else {
+                text = i18nc("@action:inmenu", "&Release");
+            }
         } else if (removable || hotpluggable) {
-            text = i18nc("@action:inmenu", "&Safely Remove");
+            if (teardownInProgress) {
+                text = i18nc("@action:inmenu", "Safely Removing…");
+            } else {
+                text = i18nc("@action:inmenu", "&Safely Remove");
+            }
             iconName = QStringLiteral("media-eject");
         } else {
-            text = i18nc("@action:inmenu", "&Unmount");
+            if (teardownInProgress) {
+                text = i18nc("@action:inmenu", "Unmounting…");
+            } else {
+                text = i18nc("@action:inmenu", "&Unmount");
+            }
             iconName = QStringLiteral("media-eject");
         }
 
         if (!iconName.isEmpty()) {
-            return new QAction(QIcon::fromTheme(iconName), text, nullptr);
+            action = new QAction(QIcon::fromTheme(iconName), text, nullptr);
         } else {
-            return new QAction(text, nullptr);
+            action = new QAction(text, nullptr);
+        }
+
+        if (teardownInProgress) {
+            action->setEnabled(false);
         }
     }
 
-    return nullptr;
+    return action;
 }
 
 QAction *KFilePlacesModel::ejectActionForIndex(const QModelIndex &index) const
@@ -1430,8 +1448,11 @@ void KFilePlacesModel::requestTeardown(const QModelIndex &index)
     Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
 
     if (access != nullptr) {
-        connect(access, &Solid::StorageAccess::teardownDone, this, [this](Solid::ErrorType error, QVariant errorData) {
-            d->storageTeardownDone(error, errorData);
+        d->teardownInProgress[access] = index;
+
+        const QString filePath = access->filePath();
+        connect(access, &Solid::StorageAccess::teardownDone, this, [this, access, filePath](Solid::ErrorType error, QVariant errorData) {
+            d->storageTeardownDone(filePath, error, errorData, access);
         });
 
         access->teardown();
@@ -1445,8 +1466,16 @@ void KFilePlacesModel::requestEject(const QModelIndex &index)
     Solid::OpticalDrive *drive = device.parent().as<Solid::OpticalDrive>();
 
     if (drive != nullptr) {
-        connect(drive, &Solid::OpticalDrive::ejectDone, this, [this](Solid::ErrorType error, QVariant errorData) {
-            d->storageTeardownDone(error, errorData);
+        d->teardownInProgress[drive] = index;
+
+        QString filePath;
+        Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
+        if (access) {
+            filePath = access->filePath();
+        }
+
+        connect(drive, &Solid::OpticalDrive::ejectDone, this, [this, filePath, drive](Solid::ErrorType error, QVariant errorData) {
+            d->storageTeardownDone(filePath, error, errorData, drive);
         });
 
         drive->eject();
@@ -1495,9 +1524,41 @@ void KFilePlacesModelPrivate::storageSetupDone(Solid::ErrorType error, const QVa
     }
 }
 
-void KFilePlacesModelPrivate::storageTeardownDone(Solid::ErrorType error, const QVariant &errorData)
+void KFilePlacesModelPrivate::storageTeardownDone(const QString &filePath, Solid::ErrorType error, const QVariant &errorData, QObject *sender)
 {
-    if (error && errorData.isValid()) {
+    QPersistentModelIndex index = teardownInProgress.take(sender);
+    if (!index.isValid()) {
+        return;
+    }
+
+    if (error == Solid::ErrorType::DeviceBusy && !filePath.isEmpty()) {
+        auto *listOpenFilesJob = new KListOpenFilesJob(filePath);
+        QObject::connect(listOpenFilesJob, &KIO::Job::result, q, [this, index, error, errorData, listOpenFilesJob]() {
+            const auto blockingProcesses = listOpenFilesJob->processInfoList();
+
+            QStringList blockingApps;
+            blockingApps.reserve(blockingProcesses.count());
+            for (const auto &process : blockingProcesses) {
+                blockingApps << process.name();
+            }
+
+            Q_EMIT q->teardownDone(index, error, errorData);
+            if (blockingProcesses.isEmpty()) {
+                Q_EMIT q->errorMessage(i18n("One or more files on this device are open within an application."));
+            } else {
+                blockingApps.removeDuplicates();
+                Q_EMIT q->errorMessage(xi18np("One or more files on this device are opened in application <application>\"%2\"</application>.",
+                                              "One or more files on this device are opened in following applications: <application>%2</application>.",
+                                              blockingApps.count(),
+                                              blockingApps.join(i18nc("separator in list of apps blocking device unmount", ", "))));
+            }
+        });
+        listOpenFilesJob->start();
+        return;
+    }
+
+    Q_EMIT q->teardownDone(index, error, errorData);
+    if (error != Solid::ErrorType::NoError && error != Solid::ErrorType::UserCanceled) {
         Q_EMIT q->errorMessage(errorData.toString());
     }
 }
@@ -1506,6 +1567,7 @@ void KFilePlacesModel::setSupportedSchemes(const QStringList &schemes)
 {
     d->supportedSchemes = schemes;
     d->reloadBookmarks();
+    Q_EMIT supportedSchemesChanged();
 }
 
 QStringList KFilePlacesModel::supportedSchemes() const
@@ -1513,4 +1575,35 @@ QStringList KFilePlacesModel::supportedSchemes() const
     return d->supportedSchemes;
 }
 
+namespace {
+QString partitionManagerPath()
+{
+    static const QString path = QStandardPaths::findExecutable(QStringLiteral("partitionmanager"));
+    return path;
+}
+} // namespace
+
+QAction *KFilePlacesModel::partitionActionForIndex(const QModelIndex &index) const
+{
+    const auto device = deviceForIndex(index);
+    if (!device.is<Solid::Block>()) {
+        return nullptr;
+    }
+
+    // Not using kservice to find partitionmanager because we need to manually invoke it so we can pass the --device argument.
+    if (partitionManagerPath().isEmpty()) {
+        return nullptr;
+    }
+
+    auto action = new QAction(QIcon::fromTheme(QStringLiteral("partitionmanager")),
+                              i18nc("@action:inmenu", "Reformat or Edit with Partition Manager"),
+                              nullptr);
+    connect(action, &QAction::triggered, this, [device] {
+        const auto block = device.as<Solid::Block>();
+        auto job = new KIO::CommandLauncherJob(partitionManagerPath(), {QStringLiteral("--device"), block->device()});
+        job->start();
+    });
+    return action;
+}
+
 #include "moc_kfileplacesmodel.cpp"
