@@ -3,6 +3,7 @@
     SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
     SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
     SPDX-FileCopyrightText: 2022 Kai Uwe Broulik <kde@broulik.de>
+    SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -26,6 +27,7 @@
 #include <QTimer>
 #include <QToolTip>
 #include <QVariantAnimation>
+#include <QWindow>
 #include <kio/deleteortrashjob.h>
 
 #include <KColorScheme>
@@ -513,25 +515,23 @@ void KFilePlacesViewDelegate::checkFreeSpace(const QModelIndex &index) const
     info.timeout.setRemainingTime(s_pollFreeSpaceInterval - 100ms);
 
     info.job = KIO::fileSystemFreeSpace(url);
-    QObject::connect(info.job,
-                     &KIO::FileSystemFreeSpaceJob::result,
-                     this,
-                     [this, persistentIndex](KIO::Job *job, KIO::filesize_t size, KIO::filesize_t available) {
-                         if (!persistentIndex.isValid()) {
-                             return;
-                         }
+    QObject::connect(info.job, &KJob::result, this, [this, info, persistentIndex]() {
+        if (!persistentIndex.isValid()) {
+            return;
+        }
 
-                         if (job->error()) {
-                             return;
-                         }
+        const auto job = info.job;
+        if (job->error()) {
+            return;
+        }
 
-                         PlaceFreeSpaceInfo &info = m_freeSpaceInfo[persistentIndex];
+        PlaceFreeSpaceInfo &info = m_freeSpaceInfo[persistentIndex];
 
-                         info.size = size;
-                         info.used = size - available;
+        info.size = job->size();
+        info.used = job->size() - job->availableSize();
 
-                         m_view->update(persistentIndex);
-                     });
+        m_view->update(persistentIndex);
+    });
 
     startPollingFreeSpace();
 }
@@ -735,7 +735,7 @@ public:
     QTimeLine m_itemDisappearTimeline;
 
     QVariantAnimation m_deviceBusyAnimation;
-    QVector<QPersistentModelIndex> m_busyDevices;
+    QList<QPersistentModelIndex> m_busyDevices;
 
     QRect m_dropRect;
     QPersistentModelIndex m_dropIndex;
@@ -1090,9 +1090,13 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     const KFilePlacesModel::GroupType type = placesModel->groupType(index);
 
     QMenu menu;
+    // Polish before creating a native window below. The style could want change the surface format
+    // of the window which will have no effect when the native window has already been created.
+    menu.ensurePolished();
 
     QAction *emptyTrash = nullptr;
     QAction *eject = nullptr;
+    QAction *partition = nullptr;
     QAction *mount = nullptr;
     QAction *teardown = nullptr;
 
@@ -1114,7 +1118,7 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         if (placeUrl.scheme() == QLatin1String("trash")) {
             emptyTrash = new QAction(QIcon::fromTheme(QStringLiteral("trash-empty")), i18nc("@action:inmenu", "Empty Trash"), &menu);
             KConfig trashConfig(QStringLiteral("trashrc"), KConfig::SimpleConfig);
-            emptyTrash->setEnabled(!trashConfig.group("Status").readEntry("Empty", true));
+            emptyTrash->setEnabled(!trashConfig.group(QStringLiteral("Status")).readEntry("Empty", true));
         }
 
         if (placesModel->isDevice(index)) {
@@ -1123,6 +1127,11 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
                 eject->setParent(&menu);
             }
 
+            partition = placesModel->partitionActionForIndex(index);
+            if (partition) {
+                partition->setParent(&menu);
+            }
+
             teardown = placesModel->teardownActionForIndex(index);
             if (teardown) {
                 teardown->setParent(&menu);
@@ -1161,7 +1170,7 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
                 KBookmark bookmark = placesModel->bookmarkForIndex(index);
                 const bool isSystemItem = bookmark.metaDataItem(QStringLiteral("isSystemItem")) == QLatin1String("true");
                 if (!isSystemItem) {
-                    remove = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action:inmenu", "Remove"), &menu);
+                    remove = new QAction(QIcon::fromTheme(QStringLiteral("bookmark-remove-symbolic")), i18nc("@action:inmenu", "Remove from Places"), &menu);
                 }
             }
 
@@ -1203,6 +1212,11 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     addActionToMenu(teardown);
     menu.addSeparator();
 
+    if (partition) {
+        addActionToMenu(partition);
+        menu.addSeparator();
+    }
+
     addActionToMenu(newTab);
     addActionToMenu(newWindow);
     addActionToMenu(highPriorityActionsPlaceholder);
@@ -1235,6 +1249,10 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     }
     delete highPriorityActionsPlaceholder;
 
+    if (window()) {
+        menu.winId();
+        menu.windowHandle()->setTransientParent(window()->windowHandle());
+    }
     QAction *result = menu.exec(event->globalPos());
 
     if (result) {
@@ -1395,7 +1413,7 @@ void KFilePlacesView::dragMoveEvent(QDragMoveEvent *event)
 
     bool autoActivate = false;
     // update the drop indicator
-    const QPoint pos = event->pos();
+    const QPoint pos = event->position().toPoint();
     const QModelIndex index = indexAt(pos);
     setDirtyRegion(d->m_dropRect);
     if (index.isValid()) {
@@ -1417,7 +1435,7 @@ void KFilePlacesView::dragMoveEvent(QDragMoveEvent *event)
     }
 
     if (d->m_dragActivationTimer) {
-        if (autoActivate && !d->m_delegate->pointIsHeaderArea(event->pos())) {
+        if (autoActivate && !d->m_delegate->pointIsHeaderArea(event->position().toPoint())) {
             QPersistentModelIndex persistentIndex(index);
             if (!d->m_pendingDragActivation.isValid() || d->m_pendingDragActivation != persistentIndex) {
                 d->m_pendingDragActivation = persistentIndex;
@@ -1434,7 +1452,7 @@ void KFilePlacesView::dragMoveEvent(QDragMoveEvent *event)
 
 void KFilePlacesView::dropEvent(QDropEvent *event)
 {
-    const QPoint pos = event->pos();
+    const QPoint pos = event->position().toPoint();
     const QModelIndex index = indexAt(pos);
     if (index.isValid()) {
         const QRect rect = visualRect(index);
@@ -1451,11 +1469,11 @@ void KFilePlacesView::dropEvent(QDropEvent *event)
                     d->m_dropUrlsMimeData->setData(format, event->mimeData()->data(format));
                 }
 
-                d->m_dropUrlsEvent = std::make_unique<QDropEvent>(event->posF(),
+                d->m_dropUrlsEvent = std::make_unique<QDropEvent>(event->position(),
                                                                   event->possibleActions(),
                                                                   d->m_dropUrlsMimeData.get(),
-                                                                  event->mouseButtons(),
-                                                                  event->keyboardModifiers());
+                                                                  event->buttons(),
+                                                                  event->modifiers());
 
                 placesModel->requestSetup(index);
             } else {
@@ -1502,12 +1520,8 @@ void KFilePlacesView::paintEvent(QPaintEvent *event)
 
         if (drawInsertIndicator) {
             // draw indicator for inserting items
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             QStyleOptionViewItem viewOpts;
             initViewItemOption(&viewOpts);
-#else
-            QStyleOptionViewItem viewOpts = viewOptions();
-#endif
 
             QBrush blendedBrush = viewOpts.palette.brush(QPalette::Normal, QPalette::Highlight);
             QColor color = blendedBrush.color();
@@ -2027,13 +2041,13 @@ void KFilePlacesViewPrivate::deviceBusyAnimationValueChanged(const QVariant &val
     }
 }
 
-void KFilePlacesView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
+void KFilePlacesView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles)
 {
     QListView::dataChanged(topLeft, bottomRight, roles);
     d->adaptItemSize();
 
     if ((roles.isEmpty() || roles.contains(KFilePlacesModel::DeviceAccessibilityRole)) && d->shouldAnimate()) {
-        QVector<QPersistentModelIndex> busyDevices;
+        QList<QPersistentModelIndex> busyDevices;
 
         auto *placesModel = qobject_cast<KFilePlacesModel *>(model());
         for (int i = 0; i < placesModel->rowCount(); ++i) {
@@ -2054,4 +2068,5 @@ void KFilePlacesView::dataChanged(const QModelIndex &topLeft, const QModelIndex
     }
 }
 
+#include "moc_kfileplacesview.cpp"
 #include "moc_kfileplacesview_p.cpp"
