@@ -11,11 +11,13 @@
 #include "jobuidelegatefactory.h"
 #include "kiogui_debug.h"
 #include "kprocessrunner_p.h"
+#include "mimetypefinderjob.h"
 #include "openwithhandlerinterface.h"
 #include "untrustedprogramhandlerinterface.h"
 
 #include <KAuthorized>
 #include <KDesktopFile>
+#include <KDesktopFileAction>
 #include <KLocalizedString>
 
 #include <QFileInfo>
@@ -38,6 +40,7 @@ public:
         }
     }
 
+    void showOpenWithDialogForMimeType();
     void showOpenWithDialog();
 
     KService::Ptr m_service;
@@ -45,9 +48,10 @@ public:
     QList<QUrl> m_urls;
     KIO::ApplicationLauncherJob::RunFlags m_runFlags;
     QString m_suggestedFileName;
+    QString m_mimeTypeName;
     QByteArray m_startupId;
-    QVector<qint64> m_pids;
-    QVector<QPointer<KProcessRunner>> m_processRunners;
+    QList<qint64> m_pids;
+    QList<QPointer<KProcessRunner>> m_processRunners;
     int m_numProcessesPending = 0;
     KIO::ApplicationLauncherJob *q;
 };
@@ -69,6 +73,13 @@ KIO::ApplicationLauncherJob::ApplicationLauncherJob(const KServiceAction &servic
     d->m_service.detach();
     d->m_service->setExec(serviceAction.exec());
 }
+KIO::ApplicationLauncherJob::ApplicationLauncherJob(const KDesktopFileAction &desktopFileAction, QObject *parent)
+    : ApplicationLauncherJob(KService::serviceByDesktopPath(desktopFileAction.desktopFilePath()), parent)
+{
+    Q_ASSERT(d->m_service);
+    d->m_service.detach();
+    d->m_service->setExec(desktopFileAction.exec());
+}
 
 KIO::ApplicationLauncherJob::ApplicationLauncherJob(QObject *parent)
     : KJob(parent)
@@ -112,7 +123,7 @@ void KIO::ApplicationLauncherJob::emitUnauthorizedError()
 void KIO::ApplicationLauncherJob::start()
 {
     if (!d->m_service) {
-        d->showOpenWithDialog();
+        d->showOpenWithDialogForMimeType();
         return;
     }
 
@@ -241,11 +252,29 @@ qint64 KIO::ApplicationLauncherJob::pid() const
     return d->m_pids.at(0);
 }
 
-QVector<qint64> KIO::ApplicationLauncherJob::pids() const
+QList<qint64> KIO::ApplicationLauncherJob::pids() const
 {
     return d->m_pids;
 }
 
+void KIO::ApplicationLauncherJobPrivate::showOpenWithDialogForMimeType()
+{
+    if (m_urls.size() == 1) {
+        auto job = new KIO::MimeTypeFinderJob(m_urls[0], q);
+        job->setFollowRedirections(true);
+        job->setSuggestedFileName(m_suggestedFileName);
+        q->connect(job, &KJob::result, q, [this, job]() {
+            if (!job->error()) {
+                m_mimeTypeName = job->mimeType();
+            }
+            showOpenWithDialog();
+        });
+        job->start();
+    } else {
+        showOpenWithDialog();
+    }
+}
+
 void KIO::ApplicationLauncherJobPrivate::showOpenWithDialog()
 {
     if (!KAuthorized::authorizeAction(QStringLiteral("openwith"))) {
@@ -278,5 +307,5 @@ void KIO::ApplicationLauncherJobPrivate::showOpenWithDialog()
         q->emitResult();
     });
 
-    openWithHandler->promptUserForApplication(q, m_urls, QString() /* MIME type name unknown */);
+    openWithHandler->promptUserForApplication(q, m_urls, m_mimeTypeName);
 }
