@@ -8,45 +8,25 @@
 */
 
 #include "kurisearchfilter.h"
-#include "ikwsopts.h"
-#include "kuriikwsfiltereng.h"
+#include "kuriikwsfiltereng_p.h"
 #include "searchprovider.h"
 
-#include <KLocalizedString>
 #include <KPluginFactory>
 
 #include <QDBusConnection>
 #include <QLoggingCategory>
 
-/**
- * IMPORTANT: If you change anything here, make sure you run the kurifiltertest
- * regression test (this should be included as part of "make test").
- */
-
-K_PLUGIN_FACTORY_WITH_JSON(KUriSearchFilterFactory, "kurisearchfilter.json", registerPlugin<KUriSearchFilter>(); registerPlugin<FilterOptions>();)
+K_PLUGIN_CLASS_WITH_JSON(KUriSearchFilter, "kurisearchfilter.json")
 
 namespace
 {
 Q_LOGGING_CATEGORY(category, "kf.kio.urifilters.ikws", QtWarningMsg)
 }
 
-KUriSearchFilter::KUriSearchFilter(QObject *parent, const QVariantList &)
-    : KUriFilterPlugin(QStringLiteral("kurisearchfilter"), parent)
-{
-    QDBusConnection::sessionBus()
-        .connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"), this, SLOT(configure()));
-}
-
 KUriSearchFilter::~KUriSearchFilter()
 {
 }
 
-void KUriSearchFilter::configure()
-{
-    qCDebug(category) << "Config reload requested...";
-    KURISearchFilterEngine::self()->loadConfig();
-}
-
 bool KUriSearchFilter::filterUri(KUriFilterData &data) const
 {
     qCDebug(category) << data.typedString() << ":" << data.uri() << ", type =" << data.uriType();
@@ -58,7 +38,7 @@ bool KUriSearchFilter::filterUri(KUriFilterData &data) const
     }
 
     QString searchTerm;
-    KURISearchFilterEngine *filter = KURISearchFilterEngine::self();
+    auto filter = KIO::KURISearchFilterEngine::self();
     SearchProvider *provider(filter->webShortcutQuery(data.typedString(), searchTerm));
     if (!provider) {
         return false;
@@ -71,18 +51,5 @@ bool KUriSearchFilter::filterUri(KUriFilterData &data) const
     return true;
 }
 
-// TODO KF6: unused, remove
-KCModule *KUriSearchFilter::configModule(QWidget *, const char *) const
-{
-    return nullptr;
-}
-
-// TODO KF6: unused, remove
-QString KUriSearchFilter::configName() const
-{
-    return i18n("Search F&ilters");
-}
-
 #include "kurisearchfilter.moc"
-
 #include "moc_kurisearchfilter.cpp"
