@@ -51,7 +51,7 @@ static QDataStream &operator>>(QDataStream &stream, BasicOperation &op)
     qint64 mtime;
     stream >> op.m_valid >> type >> op.m_renamed >> op.m_src >> op.m_dst >> op.m_target >> mtime;
     op.m_type = static_cast<BasicOperation::Type>(type);
-    op.m_mtime = QDateTime::fromSecsSinceEpoch(mtime, Qt::UTC);
+    op.m_mtime = QDateTime::fromSecsSinceEpoch(mtime, QTimeZone::UTC);
     return stream;
 }
 
@@ -170,8 +170,22 @@ CommandRecorder::CommandRecorder(FileUndoManager::CommandType op, const QList<QU
 
 void CommandRecorder::slotResult(KJob *job)
 {
-    if (job->error()) {
-        qWarning() << job->errorString();
+    const int err = job->error();
+    if (err) {
+        if (err != KIO::ERR_USER_CANCELED) {
+            qCDebug(KIO_WIDGETS) << "CommandRecorder::slotResult:" << job->errorString() << " - no undo command will be added";
+        }
+        return;
+    }
+
+    // For CopyJob, don't add an undo command unless the job actually did something,
+    // e.g. if user selected to skip all, there is nothing to undo.
+    // Note: this doesn't apply to other job types, e.g. for Mkdir m_opQueue is
+    // expected to be empty
+    if (qobject_cast<KIO::CopyJob *>(job)) {
+        if (!m_cmd.m_opQueue.isEmpty()) {
+            FileUndoManager::self()->d->addCommand(m_cmd);
+        }
         return;
     }
 
@@ -222,6 +236,7 @@ FileUndoManagerPrivate::FileUndoManagerPrivate(FileUndoManager *qq)
     , m_nextCommandIndex(1000)
     , q(qq)
 {
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MAC)
     (void)new KIOFileUndoManagerAdaptor(this);
     const QString dbusPath = QStringLiteral("/FileUndoManager");
     const QString dbusInterface = QStringLiteral("org.kde.kio.FileUndoManager");
@@ -232,6 +247,7 @@ FileUndoManagerPrivate::FileUndoManagerPrivate(FileUndoManager *qq)
     dbus.connect(QString(), dbusPath, dbusInterface, QStringLiteral("pop"), this, SLOT(slotPop()));
     dbus.connect(QString(), dbusPath, dbusInterface, QStringLiteral("push"), this, SLOT(slotPush(QByteArray)));
     dbus.connect(QString(), dbusPath, dbusInterface, QStringLiteral("unlock"), this, SLOT(slotUnlock()));
+#endif
 }
 
 FileUndoManager::FileUndoManager()
@@ -273,13 +289,6 @@ void FileUndoManagerPrivate::addCommand(const UndoCommand &cmd)
     Q_EMIT q->jobRecordingFinished(cmd.m_type);
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 79)
-bool FileUndoManager::undoAvailable() const
-{
-    return isUndoAvailable();
-}
-#endif
-
 bool FileUndoManager::isUndoAvailable() const
 {
     return !d->m_commands.isEmpty() && !d->m_lock;
@@ -429,7 +438,10 @@ void FileUndoManagerPrivate::startUndo()
 
     qCDebug(KIO_WIDGETS) << "starting with" << undoStateToString(m_undoState);
     m_undoJob = new UndoJob(m_uiInterface->showProgressInfo());
-    QMetaObject::invokeMethod(this, "undoStep", Qt::QueuedConnection);
+    auto undoFunc = [this]() {
+        undoStep();
+    };
+    QMetaObject::invokeMethod(this, undoFunc, Qt::QueuedConnection);
 }
 
 void FileUndoManagerPrivate::stopUndo(bool step)
@@ -463,7 +475,7 @@ void FileUndoManagerPrivate::slotResult(KJob *job)
         const BasicOperation op = m_currentCmd.m_opQueue.head();
         // qDebug() << "stat result for " << op.m_dst;
         KIO::StatJob *statJob = static_cast<KIO::StatJob *>(job);
-        const QDateTime mtime = QDateTime::fromSecsSinceEpoch(statJob->statResult().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, -1), Qt::UTC);
+        const QDateTime mtime = QDateTime::fromSecsSinceEpoch(statJob->statResult().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, -1), QTimeZone::UTC);
         if (mtime != op.m_mtime) {
             qCDebug(KIO_WIDGETS) << op.m_dst << "was modified after being copied. Initial timestamp" << mtime << "now" << op.m_mtime;
             QDateTime srcTime = op.m_mtime.toLocalTime();
@@ -724,14 +736,6 @@ bool FileUndoManager::UiInterface::copiedFileWasModified(const QUrl &src, const
     return result == KMessageBox::Continue;
 }
 
-bool FileUndoManager::UiInterface::confirmDeletion(const QList<QUrl> &files)
-{
-    KIO::JobUiDelegate uiDelegate;
-    uiDelegate.setWindow(d->m_parentWidget);
-    // Because undo can happen with an accidental Ctrl-Z, we want to always confirm.
-    return uiDelegate.askDeleteConfirmation(files, KIO::JobUiDelegate::Delete, KIO::JobUiDelegate::ForceConfirmation);
-}
-
 QWidget *FileUndoManager::UiInterface::parentWidget() const
 {
     return d->m_parentWidget;
