@@ -131,11 +131,7 @@ public:
     void setItem(const KFileItem &item) override
     {
         KDirModelNode::setItem(item);
-        if (item.isNull() || !item.url().isValid()) {
-            m_fsType = LocalFs;
-        } else {
-            m_fsType = FsTypeUnknown;
-        }
+        m_fsType = FsTypeUnknown;
     }
 
     // If we listed the directory, the child count is known. Otherwise it can be set via setChildCount.
@@ -470,7 +466,7 @@ void KDirModel::setDirLister(KDirLister *dirLister)
     connect(d->m_dirLister, qOverload<>(&KCoreDirLister::clear), this, [this]() {
         d->_k_slotClear();
     });
-    connect(d->m_dirLister, qOverload<const QUrl &, const QUrl &>(&KCoreDirLister::redirection), this, [this](const QUrl &oldUrl, const QUrl &newUrl) {
+    connect(d->m_dirLister, &KCoreDirLister::redirection, this, [this](const QUrl &oldUrl, const QUrl &newUrl) {
         d->_k_slotRedirection(oldUrl, newUrl);
     });
 }
@@ -986,7 +982,7 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
 {
     switch (role) {
     case Qt::EditRole:
-        if (index.column() == Name && value.type() == QVariant::String) {
+        if (index.column() == Name && value.typeId() == QMetaType::QString) {
             Q_ASSERT(index.isValid());
             KDirModelNode *node = static_cast<KDirModelNode *>(index.internalPointer());
             const KFileItem &item = node->item();
@@ -1010,10 +1006,10 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
             KDirModelNode *node = static_cast<KDirModelNode *>(index.internalPointer());
             // qDebug() << "setting icon for " << node->item()->url();
             Q_ASSERT(node);
-            if (value.type() == QVariant::Icon) {
+            if (value.typeId() == QMetaType::QIcon) {
                 const QIcon icon(qvariant_cast<QIcon>(value));
                 node->setPreview(icon);
-            } else if (value.type() == QVariant::Pixmap) {
+            } else if (value.typeId() == QMetaType::QPixmap) {
                 node->setPreview(qvariant_cast<QPixmap>(value));
             }
             Q_EMIT dataChanged(index, index);
@@ -1184,15 +1180,6 @@ KFileItem KDirModel::itemForIndex(const QModelIndex &index) const
     }
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 0)
-QModelIndex KDirModel::indexForItem(const KFileItem *item) const
-{
-    // Note that we can only use the URL here, not the pointer.
-    // KFileItems can be copied.
-    return indexForUrl(item->url()); // O(n)
-}
-#endif
-
 QModelIndex KDirModel::indexForItem(const KFileItem &item) const
 {
     return indexForUrl(item.url()); // O(n)
@@ -1342,7 +1329,8 @@ bool KDirModel::canFetchMore(const QModelIndex &parent) const
 
     KDirModelNode *node = static_cast<KDirModelNode *>(parent.internalPointer());
     const KFileItem &item = node->item();
-    return item.isDir() && !static_cast<KDirModelDirNode *>(node)->isPopulated() && static_cast<KDirModelDirNode *>(node)->m_childNodes.isEmpty();
+    return item.isDir() && !static_cast<KDirModelDirNode *>(node)->isOnNetwork() && !static_cast<KDirModelDirNode *>(node)->isPopulated()
+        && static_cast<KDirModelDirNode *>(node)->m_childNodes.isEmpty();
 }
 
 void KDirModel::fetchMore(const QModelIndex &parent)
