@@ -13,18 +13,16 @@
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KDesktopFile>
+#include <KDesktopFileAction>
 #include <KFileUtils>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/JobUiDelegate>
 #include <KLocalizedString>
-#include <KMimeTypeTrader>
 #include <KPluginFactory>
 #include <KPluginMetaData>
 #include <KSandbox>
-#include <KServiceTypeTrader>
 #include <jobuidelegatefactory.h>
 #include <kapplicationtrader.h>
-#include <kdesktopfileactions.h>
 #include <kdirnotify.h>
 #include <kurlauthorized.h>
 
@@ -86,10 +84,6 @@ class PopupServices
 public:
     ServiceList &selectList(const QString &priority, const QString &submenuName);
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-    ServiceList builtin;
-#endif
-
     ServiceList user;
     ServiceList userToplevel;
     ServiceList userPriority;
@@ -149,11 +143,18 @@ int KFileItemActionsPrivate::insertServicesSubmenus(const QMap<QString, ServiceL
         }
 
         QMenu *actionSubmenu = new QMenu(menu);
-        actionSubmenu->setTitle(it.key());
-        actionSubmenu->setIcon(QIcon::fromTheme(it.value().first().icon()));
-        actionSubmenu->menuAction()->setObjectName(QStringLiteral("services_submenu")); // for the unittest
-        menu->addMenu(actionSubmenu);
-        count += insertServices(it.value(), actionSubmenu, isBuiltin);
+        const int servicesAddedCount = insertServices(it.value(), actionSubmenu, isBuiltin);
+
+        if (servicesAddedCount > 0) {
+            count += servicesAddedCount;
+            actionSubmenu->setTitle(it.key());
+            actionSubmenu->setIcon(QIcon::fromTheme(it.value().first().icon()));
+            actionSubmenu->menuAction()->setObjectName(QStringLiteral("services_submenu")); // for the unittest
+            menu->addMenu(actionSubmenu);
+        } else {
+            // avoid empty sub-menus
+            delete actionSubmenu;
+        }
     }
 
     return count;
@@ -162,11 +163,11 @@ int KFileItemActionsPrivate::insertServicesSubmenus(const QMap<QString, ServiceL
 int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu, bool isBuiltin)
 {
     ServiceList sortedList = list;
-    std::sort(sortedList.begin(), sortedList.end(), [](const KServiceAction &a1, const KServiceAction &a2) {
+    std::sort(sortedList.begin(), sortedList.end(), [](const KDesktopFileAction &a1, const KDesktopFileAction &a2) {
         return a1.name() < a2.name();
     });
     int count = 0;
-    for (const KServiceAction &serviceAction : std::as_const(sortedList)) {
+    for (const KDesktopFileAction &serviceAction : std::as_const(sortedList)) {
         if (serviceAction.isSeparator()) {
             const QList<QAction *> actions = menu->actions();
             if (!actions.isEmpty() && !actions.last()->isSeparator()) {
@@ -175,10 +176,10 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu
             continue;
         }
 
-        if (isBuiltin || !serviceAction.noDisplay()) {
+        if (isBuiltin) {
             QAction *act = new QAction(q);
             act->setObjectName(QStringLiteral("menuaction")); // for the unittest
-            QString text = serviceAction.text();
+            QString text = serviceAction.name();
             text.replace(QLatin1Char('&'), QLatin1String("&&"));
             act->setText(text);
             if (!serviceAction.icon().isEmpty()) {
@@ -197,7 +198,7 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu
 
 void KFileItemActionsPrivate::slotExecuteService(QAction *act)
 {
-    const KServiceAction serviceAction = act->data().value<KServiceAction>();
+    const KDesktopFileAction serviceAction = act->data().value<KDesktopFileAction>();
     if (KAuthorized::authorizeAction(serviceAction.name())) {
         auto *job = new KIO::ApplicationLauncherJob(serviceAction);
         job->setUrls(m_props.urlList());
@@ -227,20 +228,6 @@ void KFileItemActions::setItemListProperties(const KFileItemListProperties &item
     }
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 79)
-int KFileItemActions::addServiceActionsTo(QMenu *mainMenu)
-{
-    return d->addServiceActionsTo(mainMenu, {}, {}).userItemCount;
-}
-#endif
-
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 79)
-int KFileItemActions::addPluginActionsTo(QMenu *mainMenu)
-{
-    return d->addPluginActionsTo(mainMenu, mainMenu, {});
-}
-#endif
-
 void KFileItemActions::addActionsTo(QMenu *menu, MenuActionSources sources, const QList<QAction *> &additionalActions, const QStringList &excludeList)
 {
     QMenu *actionsMenu = menu;
@@ -263,15 +250,6 @@ KService::List KFileItemActions::associatedApplications(const QStringList &mimeT
     return KFileItemActionsPrivate::associatedApplications(mimeTypeList, QString(), QStringList{});
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 83)
-// static
-KService::List KFileItemActions::associatedApplications(const QStringList &mimeTypeList, const QString &traderConstraint)
-{
-    return KFileItemActionsPrivate::associatedApplications(mimeTypeList, traderConstraint, QStringList{});
-}
-
-#endif
-
 static KService::Ptr preferredService(const QString &mimeType, const QStringList &excludedDesktopEntryNames, const QString &constraint)
 {
     KService::List services;
@@ -280,34 +258,9 @@ static KService::Ptr preferredService(const QString &mimeType, const QStringList
             return !excludedDesktopEntryNames.contains(serv->desktopEntryName());
         });
     }
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-    else {
-        Q_ASSERT(excludedDesktopEntryNames.isEmpty());
-        // KMimeTypeTrader::preferredService doesn't take a constraint
-        QT_WARNING_PUSH
-        QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-        QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-        services = KMimeTypeTrader::self()->query(mimeType, QStringLiteral("Application"), constraint);
-        QT_WARNING_POP
-    }
-#endif
     return services.isEmpty() ? KService::Ptr() : services.first();
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-void KFileItemActions::addOpenWithActionsTo(QMenu *topMenu, const QString &traderConstraint)
-{
-    d->insertOpenWithActionsTo(nullptr, topMenu, QStringList(), traderConstraint);
-}
-#endif
-
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-void KFileItemActions::insertOpenWithActionsTo(QAction *before, QMenu *topMenu, const QString &traderConstraint)
-{
-    d->insertOpenWithActionsTo(before, topMenu, QStringList(), traderConstraint);
-}
-#endif
-
 void KFileItemActions::insertOpenWithActionsTo(QAction *before, QMenu *topMenu, const QStringList &excludedDesktopEntryNames)
 {
     d->insertOpenWithActionsTo(before, topMenu, excludedDesktopEntryNames, QString());
@@ -342,15 +295,6 @@ void KFileItemActionsPrivate::slotRunPreferredApplications()
     }
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 83)
-void KFileItemActions::runPreferredApplications(const KFileItemList &fileOpenList, const QString &traderConstraint)
-{
-    d->m_fileOpenList = fileOpenList;
-    d->m_traderConstraint = traderConstraint;
-    d->slotRunPreferredApplications();
-}
-#endif
-
 void KFileItemActions::runPreferredApplications(const KFileItemList &fileOpenList)
 {
     d->m_fileOpenList = fileOpenList;
@@ -445,34 +389,6 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
     if (!KIOSKAuthorizedAction(cfg)) {
         return false;
     }
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 76) && !defined(KIO_ANDROID_STUB)
-    if (cfg.hasKey("X-KDE-ShowIfRunning")) {
-        qCWarning(KIO_WIDGETS) << "The property X-KDE-ShowIfRunning is deprecated and will be removed in future releases";
-        const QString app = cfg.readEntry("X-KDE-ShowIfRunning");
-        if (QDBusConnection::sessionBus().interface()->isServiceRegistered(app)) {
-            return false;
-        }
-    }
-    if (cfg.hasKey("X-KDE-ShowIfDBusCall")) {
-        qCWarning(KIO_WIDGETS) << "The property X-KDE-ShowIfDBusCall is deprecated and will be removed in future releases";
-        QString calldata = cfg.readEntry("X-KDE-ShowIfDBusCall");
-        const QStringList parts = calldata.split(QLatin1Char(' '));
-        const QString &app = parts.at(0);
-        const QString &obj = parts.at(1);
-        QString interface = parts.at(2);
-        QString method;
-        int pos = interface.lastIndexOf(QLatin1Char('.'));
-        if (pos != -1) {
-            method = interface.mid(pos + 1);
-            interface.truncate(pos);
-        }
-
-        QDBusMessage reply = QDBusInterface(app, obj, interface).call(method, QUrl::toStringList(urlList));
-        if (reply.arguments().count() < 1 || reply.arguments().at(0).type() != QVariant::Bool || !reply.arguments().at(0).toBool()) {
-            return false;
-        }
-    }
-#endif
     if (cfg.hasKey("X-KDE-Protocol")) {
         const QString theProtocol = cfg.readEntry("X-KDE-Protocol");
         if (theProtocol.startsWith(QLatin1Char('!'))) { // Is it excluded?
@@ -494,16 +410,6 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
         return false;
     }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 76)
-    if (cfg.hasKey("X-KDE-Require")) {
-        qCWarning(KIO_WIDGETS) << "The property X-KDE-Require is deprecated and will be removed in future releases";
-        const QStringList capabilities = cfg.readEntry("X-KDE-Require", QStringList());
-        if (capabilities.contains(QLatin1String("Write")) && !m_props.supportsWriting()) {
-            return false;
-        }
-    }
-#endif
-
     const auto requiredNumbers = cfg.readEntry("X-KDE-RequiredNumberOfUrls", QList<int>());
     if (!requiredNumbers.isEmpty() && !requiredNumbers.contains(urlList.count())) {
         return false;
@@ -525,10 +431,7 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
 
 bool KFileItemActionsPrivate::checkTypesMatch(const KConfigGroup &cfg) const
 {
-    // Like KService, we support ServiceTypes, X-KDE-ServiceTypes, and MimeType.
-    const QStringList types = cfg.readEntry("ServiceTypes", QStringList())
-        << cfg.readEntry("X-KDE-ServiceTypes", QStringList()) << cfg.readXdgListEntry("MimeType");
-
+    const QStringList types = cfg.readXdgListEntry("MimeType");
     if (types.isEmpty()) {
         return false;
     }
@@ -547,23 +450,13 @@ KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu, const QList<QActio
     const KFileItem &firstItem = items.first();
     const QString protocol = firstItem.url().scheme(); // assumed to be the same for all items
     const bool isLocal = !firstItem.localPath().isEmpty();
-    const bool isSingleLocal = items.count() == 1 && isLocal;
-    const QList<QUrl> urlList = m_props.urlList();
 
     KIO::PopupServices s;
 
-    // TODO KF6 remove mention of "builtin" (deprecated)
-    // 1 - Look for builtin services
-    if (isSingleLocal && m_props.mimeType() == QLatin1String("application/x-desktop")) {
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-        // Get builtin services, like mount/unmount
-        s.builtin = KDesktopFileActions::builtinServices(QUrl::fromLocalFile(firstItem.localPath()));
-#endif
-    }
-
     // 2 - Look for "servicemenus" bindings (user-defined services)
 
     // first check the .directory if this is a directory
+    const bool isSingleLocal = items.count() == 1 && isLocal;
     if (m_props.isDirectory() && isSingleLocal) {
         const QString dotDirectoryFile = QUrl::fromLocalFile(firstItem.localPath()).path().append(QLatin1String("/.directory"));
         if (QFile::exists(dotDirectoryFile)) {
@@ -574,24 +467,24 @@ KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu, const QList<QActio
                 const QString priority = cfg.readEntry("X-KDE-Priority");
                 const QString submenuName = cfg.readEntry("X-KDE-Submenu");
                 ServiceList &list = s.selectList(priority, submenuName);
-                list += KDesktopFileActions::userDefinedServices(KService(dotDirectoryFile), true);
+                list += desktopFile.actions();
             }
         }
     }
 
-    const KConfigGroup showGroup = m_config.group("Show");
+    const KConfigGroup showGroup = m_config.group(QStringLiteral("Show"));
 
     const QMimeDatabase db;
     const QStringList files = serviceMenuFilePaths();
     for (const QString &file : files) {
         const KDesktopFile desktopFile(file);
         const KConfigGroup cfg = desktopFile.desktopGroup();
-
         if (!shouldDisplayServiceMenu(cfg, protocol)) {
             continue;
         }
 
-        if (cfg.hasKey("Actions") || cfg.hasKey("X-KDE-GetActionMenu")) {
+        const QList<KDesktopFileAction> actions = desktopFile.actions();
+        if (!actions.isEmpty()) {
             if (!checkTypesMatch(cfg)) {
                 continue;
             }
@@ -600,8 +493,7 @@ KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu, const QList<QActio
             const QString submenuName = cfg.readEntry("X-KDE-Submenu");
 
             ServiceList &list = s.selectList(priority, submenuName);
-            const ServiceList userServices = KDesktopFileActions::userDefinedServices(KService(file), isLocal, urlList);
-            std::copy_if(userServices.cbegin(), userServices.cend(), std::back_inserter(list), [&excludeList, &showGroup](const KServiceAction &srvAction) {
+            std::copy_if(actions.cbegin(), actions.cend(), std::back_inserter(list), [&excludeList, &showGroup](const KDesktopFileAction &srvAction) {
                 return showGroup.readEntry(srvAction.name(), true) && !excludeList.contains(srvAction.name());
             });
         }
@@ -626,10 +518,6 @@ KFileItemActionsPrivate::addServiceActionsTo(QMenu *mainMenu, const QList<QActio
     userItemCount += insertServicesSubmenus(s.userSubmenus, actionMenu, false);
     userItemCount += insertServices(s.user, actionMenu, false);
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-    userItemCount += insertServices(s.builtin, mainMenu, true);
-#endif
-
     userItemCount += insertServicesSubmenus(s.userToplevelSubmenus, mainMenu, false);
     userItemCount += insertServices(s.userToplevel, mainMenu, false);
 
@@ -646,18 +534,16 @@ int KFileItemActionsPrivate::addPluginActionsTo(QMenu *mainMenu, QMenu *actionsM
     QStringList addedPlugins;
     int itemCount = 0;
 
-    const KConfigGroup showGroup = m_config.group("Show");
+    const KConfigGroup showGroup = m_config.group(QStringLiteral("Show"));
 
     const QMimeDatabase db;
-    const auto jsonPlugins =
-        KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/kfileitemaction"),
-                                     [&db, commonMimeType](const KPluginMetaData &metaData) {
-                                         auto mimeType = db.mimeTypeForName(commonMimeType);
-                                         const QStringList list = metaData.mimeTypes();
-                                         return std::any_of(list.constBegin(), list.constEnd(), [mimeType](const QString &supportedMimeType) {
-                                             return mimeType.inherits(supportedMimeType);
-                                         });
-                                     });
+    const auto jsonPlugins = KPluginMetaData::findPlugins(QStringLiteral("kf6/kfileitemaction"), [&db, commonMimeType](const KPluginMetaData &metaData) {
+        auto mimeType = db.mimeTypeForName(commonMimeType);
+        const QStringList list = metaData.mimeTypes();
+        return std::any_of(list.constBegin(), list.constEnd(), [mimeType](const QString &supportedMimeType) {
+            return mimeType.inherits(supportedMimeType);
+        });
+    });
 
     for (const auto &jsonMetadata : jsonPlugins) {
         // The plugin has been disabled
@@ -685,44 +571,6 @@ int KFileItemActionsPrivate::addPluginActionsTo(QMenu *mainMenu, QMenu *actionsM
         }
     }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    const KService::List fileItemPlugins =
-        KMimeTypeTrader::self()->query(commonMimeType, QStringLiteral("KFileItemAction/Plugin"), QStringLiteral("exist Library"));
-    for (const auto &service : fileItemPlugins) {
-        if (!showGroup.readEntry(service->desktopEntryName(), true)) {
-            // The plugin has been disabled
-            continue;
-        }
-
-        // The plugin also has a JSON metadata and has already been added.
-        if (addedPlugins.contains(service->desktopEntryName())) {
-            continue;
-        }
-
-        KAbstractFileItemActionPlugin *abstractPlugin = m_loadedPlugins.value(service->desktopEntryName());
-        if (!abstractPlugin) {
-            abstractPlugin = service->createInstance<KAbstractFileItemActionPlugin>(this);
-            if (abstractPlugin) {
-                connect(abstractPlugin, &KAbstractFileItemActionPlugin::error, q, &KFileItemActions::error);
-                m_loadedPlugins.insert(service->desktopEntryName(), abstractPlugin);
-                qCWarning(KIO_WIDGETS) << "The" << service->name()
-                                       << "plugin still installs the desktop file for plugin loading. Please use JSON metadata instead, see "
-                                       << "KAbstractFileItemActionPlugin class docs for instructions.";
-            }
-        }
-        if (abstractPlugin) {
-            auto actions = abstractPlugin->actions(m_props, m_parentWidget);
-            itemCount += actions.count();
-            mainMenu->addActions(actions);
-            addedPlugins.append(service->desktopEntryName());
-        }
-    }
-    QT_WARNING_POP
-#endif
-
     return itemCount;
 }
 
@@ -739,16 +587,6 @@ KFileItemActionsPrivate::associatedApplications(const QStringList &mimeTypeList,
             return !excludedDesktopEntryNames.contains(service->desktopEntryName());
         });
     }
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-    else {
-        Q_ASSERT(excludedDesktopEntryNames.isEmpty());
-        QT_WARNING_PUSH
-        QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-        QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-        firstOffers = KMimeTypeTrader::self()->query(mimeTypeList.first(), QStringLiteral("Application"), traderConstraint);
-        QT_WARNING_POP
-    }
-#endif
 
     QList<KFileItemActionsPrivate::ServiceRank> rankings;
     QStringList serviceList;
@@ -775,16 +613,7 @@ KFileItemActionsPrivate::associatedApplications(const QStringList &mimeTypeList,
                 return !excludedDesktopEntryNames.contains(service->desktopEntryName());
             });
         }
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-        else {
-            QT_WARNING_PUSH
-            QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-            QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-            Q_ASSERT(excludedDesktopEntryNames.isEmpty());
-            offers = KMimeTypeTrader::self()->query(mimeTypeList[j], QStringLiteral("Application"), traderConstraint);
-            QT_WARNING_POP
-        }
-#endif
+
         subservice.reserve(offers.count());
         for (int i = 0; i != offers.count(); ++i) {
             const QString serviceId = offers[i]->storageId();
@@ -945,14 +774,10 @@ void KFileItemActionsPrivate::insertOpenWithActionsTo(QAction *before,
 
     if (m_props.mimeType() == QLatin1String("application/x-desktop")) {
         const QString path = firstItem.localPath();
-        const KDesktopFile desktopFile(path);
-        const KConfigGroup cfg = desktopFile.desktopGroup();
-
-        const ServiceList services = KDesktopFileActions::userDefinedServices(KService(path), true /*isLocal*/);
-
-        for (const KServiceAction &serviceAction : services) {
+        const ServiceList services = KDesktopFile(path).actions();
+        for (const KDesktopFileAction &serviceAction : services) {
             QAction *action = new QAction(this);
-            action->setText(serviceAction.text());
+            action->setText(serviceAction.name());
             action->setIcon(QIcon::fromTheme(serviceAction.icon()));
 
             connect(action, &QAction::triggered, this, [serviceAction] {
@@ -974,18 +799,8 @@ QStringList KFileItemActionsPrivate::serviceMenuFilePaths()
 {
     QStringList filePaths;
 
-    // Use old KServiceTypeTrader code path
     std::set<QString> uniqueFileNames;
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 85)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_DEPRECATED
-    const KService::List entries = KServiceTypeTrader::self()->query(QStringLiteral("KonqPopupMenu/Plugin"));
-    QT_WARNING_POP
-    for (const KServicePtr &entry : entries) {
-        filePaths << QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + entry->entryPath());
-        uniqueFileNames.insert(entry->entryPath().split(QLatin1Char('/')).last());
-    }
-#endif
+
     // Load servicemenus from new install location
     const QStringList paths =
         QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kio/servicemenus"), QStandardPaths::LocateDirectory);
@@ -998,18 +813,10 @@ QStringList KFileItemActionsPrivate::serviceMenuFilePaths()
     return filePaths;
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 82)
-QAction *KFileItemActions::preferredOpenWithAction(const QString &traderConstraint)
-{
-    const KService::List offers = associatedApplications(d->m_mimeTypeList, traderConstraint);
-    if (offers.isEmpty()) {
-        return nullptr;
-    }
-    return d->createAppAction(offers.first(), true);
-}
-#endif
-
 void KFileItemActions::setParentWidget(QWidget *widget)
 {
     d->m_parentWidget = widget;
 }
+
+#include "moc_kfileitemactions.cpp"
+#include "moc_kfileitemactions_p.cpp"
