@@ -15,9 +15,10 @@
 #include <QUrl>
 
 #include "kiowidgets_export.h"
-#include <KPageDialog>
 #include <kfileitem.h>
 
+#include <KPageDialog>
+
 #include <memory>
 
 class KPropertiesDialogPrivate;
@@ -136,7 +137,7 @@ public:
      * Creates an empty properties dialog (for applications that want use
      * a standard dialog, but for things not doable via the plugin-mechanism).
      *
-     * @param title is the string display as the "filename" in the caption of the dialog.
+     * @param title is the string display as the "filename" in the title of the dialog.
      * @param parent is the parent of the dialog widget.
      */
     explicit KPropertiesDialog(const QString &title, QWidget *parent = nullptr);
@@ -213,17 +214,6 @@ public:
      */
     void insertPlugin(KPropertiesDialogPlugin *plugin);
 
-#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0, use url()
-     */
-    KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KPropertiesDialog::url()")
-    QUrl kurl() const
-    {
-        return url();
-    }
-#endif
-
     /**
      * The URL of the file that has its properties being displayed.
      * This is only valid if the KPropertiesDialog was created/shown
@@ -314,19 +304,6 @@ public:
     using KPageDialog::buttonBox;
 
 public Q_SLOTS:
-    /**
-     * Called when the user presses 'Ok'.
-     * @deprecated since 5.25, use accept()
-     */
-    KIOWIDGETS_DEPRECATED_VERSION(5, 25, "Use KPropertiesDialog::accept()")
-    virtual void slotOk();
-    /**
-     * Called when the user presses 'Cancel'.
-     * @deprecated since 5.25, use reject()
-     */
-    KIOWIDGETS_DEPRECATED_VERSION(5, 25, "Use KPropertiesDialog::reject()")
-    virtual void slotCancel();
-
     /**
      * Called when the user presses 'Ok'.
      * @since 5.25
@@ -364,10 +341,6 @@ Q_SIGNALS:
      */
     void saveAs(const QUrl &oldUrl, QUrl &newUrl);
 
-Q_SIGNALS:
-    // TODO KF6: remove this, not used anymore
-    void leaveModality();
-
 private:
     std::unique_ptr<KPropertiesDialogPrivate> d;
 
@@ -383,8 +356,12 @@ class KPropertiesDialogPluginPrivate;
  * It's up to the plugin to insert pages into the parent dialog.
  *
  * To make a plugin available, ensure it has embedded json metadata (look for
- * K_PLUGIN_CLASS_WITH_JSON) and install the plugin into kf5/propertiesdialog. The metadata
- * can contain the MIME types for which the plugin should be created.
+ * K_PLUGIN_CLASS_WITH_JSON) and install the plugin in "\<plugins_dir>/kf5/propertiesdialog/".
+ * (By default KDE uses the same plugins dir as Qt, you can find the @c plugins_dir path on
+ * your system by running <tt>qtpaths --plugin-dir</tt> or <tt>qmake QT_INSTALL_PLUGINS</tt>
+ * in terminal).
+ *
+ * The metadata can contain the MIME types for which the plugin should be created.
  * For instance:
  * @verbatim
    {
@@ -417,16 +394,6 @@ public:
      */
     virtual void applyChanges();
 
-#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(4, 1)
-    /**
-     * Convenience method for most ::supports methods
-     * @return true if the file is a local, regular, readable, desktop file
-     * @deprecated Since 4.1, use KFileItem::isDesktopFile
-     */
-    KIOWIDGETS_DEPRECATED_VERSION(4, 1, "Use KFileItem::isDesktopFile()")
-    static bool isDesktopFile(const KFileItem &_item);
-#endif
-
     void setDirty(bool b);
     bool isDirty() const;
 
