@@ -10,6 +10,7 @@
 #include "kio/renamedialog.h"
 #include "../utils_p.h"
 #include "kio_widgets_debug.h"
+#include "kshell.h"
 
 #include <QApplication>
 #include <QCheckBox>
@@ -366,7 +367,13 @@ RenameDialog::RenameDialog(QWidget *parent,
         pLayout->addLayout(gridLayout);
 
         int gridRow = 0;
-        QLabel *titleLabel = new QLabel(i18n("This action will overwrite the destination."), this);
+        auto title = i18n("This action will overwrite the destination.");
+        if (d->srcItem.isDir() && d->destItem.isDir()) {
+            title = i18n("This action will merge the contents of '%1' into '%2'.",
+                         KShell::tildeCollapse(d->src.toDisplayString(QUrl::PreferLocalFile)),
+                         KShell::tildeCollapse(d->dest.toDisplayString(QUrl::PreferLocalFile)));
+        }
+        QLabel *titleLabel = new QLabel(title, this);
         gridLayout->addWidget(titleLabel, gridRow, 0, 1, 2); // takes the complete first line
 
         gridLayout->setRowMinimumHeight(++gridRow, 15); // spacer
@@ -449,7 +456,7 @@ RenameDialog::RenameDialog(QWidget *parent,
                     i18n("The files are likely to be identical: they have the same size and their contents are the same at the beginning, middle and end."));
                 pixmapLabel->setCursor(Qt::WhatsThisCursor);
 
-                QHBoxLayout *hbox = new QHBoxLayout(this);
+                QHBoxLayout *hbox = new QHBoxLayout();
                 hbox->addWidget(filesIdenticalLabel);
                 hbox->addWidget(pixmapLabel);
                 gridLayout->addLayout(hbox, gridRow + 1, 1);
@@ -616,13 +623,6 @@ void RenameDialog::renamePressed()
     }
 }
 
-#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
-QString RenameDialog::suggestName(const QUrl &baseURL, const QString &oldName)
-{
-    return KFileUtils::suggestName(baseURL, oldName);
-}
-#endif
-
 // Propose button clicked
 void RenameDialog::suggestNewNamePressed()
 {
@@ -644,11 +644,6 @@ void RenameDialog::skipPressed()
     }
 }
 
-void RenameDialog::autoSkipPressed()
-{
-    done(Result_AutoSkip);
-}
-
 void RenameDialog::overwritePressed()
 {
     if (d->bApplyAll && d->bApplyAll->isChecked()) {
